/**
 * Debugging Protocol 1.1 Domains
 * Generated on Wed Feb 10 2016 15:20:19 GMT-0800 (PST)
 */
import { IDebuggingProtocolClient } from "chrome-debugging-client";
export declare class Inspector {
    private _evaluateForTestInFrontend;
    private _inspect;
    private _detached;
    private _targetCrashed;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Enables inspector domain notifications. */
    enable(): Promise<void>;
    /** Disables inspector domain notifications. */
    disable(): Promise<void>;
    evaluateForTestInFrontend: Inspector.evaluateForTestInFrontend_Handler;
    inspect: Inspector.inspect_Handler;
    /** Fired when remote debugging connection is about to be terminated. Contains detach reason. */
    detached: Inspector.detached_Handler;
    /** Fired when debugging target has crashed */
    targetCrashed: Inspector.targetCrashed_Handler;
}
export declare namespace Inspector {
    type evaluateForTestInFrontend_Parameters = {
        testCallId: number;
        script: string;
    };
    type evaluateForTestInFrontend_Handler = (params: evaluateForTestInFrontend_Parameters) => void;
    type inspect_Parameters = {
        object: Runtime.RemoteObject;
        hints: any;
    };
    type inspect_Handler = (params: inspect_Parameters) => void;
    type detached_Parameters = {
        /** The reason why connection has been terminated. */
        reason: string;
    };
    type detached_Handler = (params: detached_Parameters) => void;
    type targetCrashed_Handler = () => void;
}
export declare class Memory {
    private _client;
    constructor(client: IDebuggingProtocolClient);
    getDOMCounters(): Promise<Memory.getDOMCounters_Return>;
    /** Enable/disable suppressing memory pressure notifications in all processes. */
    setPressureNotificationsSuppressed(params: Memory.setPressureNotificationsSuppressed_Parameters): Promise<void>;
    /** Simulate a memory pressure notification in all processes. */
    simulatePressureNotification(params: Memory.simulatePressureNotification_Parameters): Promise<void>;
}
export declare namespace Memory {
    /** Memory pressure level. */
    type PressureLevel = "moderate" | "critical";
    type getDOMCounters_Return = {
        documents: number;
        nodes: number;
        jsEventListeners: number;
    };
    type setPressureNotificationsSuppressed_Parameters = {
        /** If true, memory pressure notifications will be suppressed. */
        suppressed: boolean;
    };
    type simulatePressureNotification_Parameters = {
        /** Memory pressure level of the notification. */
        level: PressureLevel;
    };
}
/** Actions and events related to the inspected page belong to the page domain. */
export declare class Page {
    private _domContentEventFired;
    private _loadEventFired;
    private _frameAttached;
    private _frameNavigated;
    private _frameDetached;
    private _frameStartedLoading;
    private _frameStoppedLoading;
    private _frameScheduledNavigation;
    private _frameClearedScheduledNavigation;
    private _frameResized;
    private _javascriptDialogOpening;
    private _javascriptDialogClosed;
    private _screencastFrame;
    private _screencastVisibilityChanged;
    private _colorPicked;
    private _interstitialShown;
    private _interstitialHidden;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Enables page domain notifications. */
    enable(): Promise<void>;
    /** Disables page domain notifications. */
    disable(): Promise<void>;
    addScriptToEvaluateOnLoad(params: Page.addScriptToEvaluateOnLoad_Parameters): Promise<Page.addScriptToEvaluateOnLoad_Return>;
    removeScriptToEvaluateOnLoad(params: Page.removeScriptToEvaluateOnLoad_Parameters): Promise<void>;
    /** Reloads given page optionally ignoring the cache. */
    reload(params: Page.reload_Parameters): Promise<void>;
    /** Navigates current page to the given URL. */
    navigate(params: Page.navigate_Parameters): Promise<Page.navigate_Return>;
    /** Returns navigation history for the current page. */
    getNavigationHistory(params: Page.getNavigationHistory_Parameters): Promise<Page.getNavigationHistory_Return>;
    /** Navigates current page to the given history entry. */
    navigateToHistoryEntry(params: Page.navigateToHistoryEntry_Parameters): Promise<void>;
    /** Returns all browser cookies. Depending on the backend support, will return detailed cookie information in the <code>cookies</code> field. */
    getCookies(): Promise<Page.getCookies_Return>;
    /** Deletes browser cookie with given name, domain and path. */
    deleteCookie(params: Page.deleteCookie_Parameters): Promise<void>;
    /** Returns present frame / resource tree structure. */
    getResourceTree(): Promise<Page.getResourceTree_Return>;
    /** Returns content of the given resource. */
    getResourceContent(params: Page.getResourceContent_Parameters): Promise<Page.getResourceContent_Return>;
    /** Searches for given string in resource content. */
    searchInResource(params: Page.searchInResource_Parameters): Promise<Page.searchInResource_Return>;
    /** Sets given markup as the document's HTML. */
    setDocumentContent(params: Page.setDocumentContent_Parameters): Promise<void>;
    /** Overrides the values of device screen dimensions (window.screen.width, window.screen.height, window.innerWidth, window.innerHeight, and "device-width"/"device-height"-related CSS media query results). */
    setDeviceMetricsOverride(params: Page.setDeviceMetricsOverride_Parameters): Promise<void>;
    /** Clears the overriden device metrics. */
    clearDeviceMetricsOverride(): Promise<void>;
    /** Overrides the Geolocation Position or Error. Omitting any of the parameters emulates position unavailable. */
    setGeolocationOverride(params: Page.setGeolocationOverride_Parameters): Promise<void>;
    /** Clears the overriden Geolocation Position and Error. */
    clearGeolocationOverride(): Promise<void>;
    /** Overrides the Device Orientation. */
    setDeviceOrientationOverride(params: Page.setDeviceOrientationOverride_Parameters): Promise<void>;
    /** Clears the overridden Device Orientation. */
    clearDeviceOrientationOverride(): Promise<void>;
    /** Toggles mouse event-based touch event emulation. */
    setTouchEmulationEnabled(params: Page.setTouchEmulationEnabled_Parameters): Promise<void>;
    /** Capture page screenshot. */
    captureScreenshot(params: Page.captureScreenshot_Parameters): Promise<Page.captureScreenshot_Return>;
    /** Starts sending each frame using the <code>screencastFrame</code> event. */
    startScreencast(params: Page.startScreencast_Parameters): Promise<void>;
    /** Stops sending each frame in the <code>screencastFrame</code>. */
    stopScreencast(): Promise<void>;
    /** Acknowledges that a screencast frame has been received by the frontend. */
    screencastFrameAck(params: Page.screencastFrameAck_Parameters): Promise<void>;
    /** Accepts or dismisses a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload). */
    handleJavaScriptDialog(params: Page.handleJavaScriptDialog_Parameters): Promise<void>;
    /** Shows / hides color picker */
    setColorPickerEnabled(params: Page.setColorPickerEnabled_Parameters): Promise<void>;
    /** Sets overlay message. */
    setOverlayMessage(params: Page.setOverlayMessage_Parameters): Promise<void>;
    domContentEventFired: Page.domContentEventFired_Handler;
    loadEventFired: Page.loadEventFired_Handler;
    /** Fired when frame has been attached to its parent. */
    frameAttached: Page.frameAttached_Handler;
    /** Fired once navigation of the frame has completed. Frame is now associated with the new loader. */
    frameNavigated: Page.frameNavigated_Handler;
    /** Fired when frame has been detached from its parent. */
    frameDetached: Page.frameDetached_Handler;
    /** Fired when frame has started loading. */
    frameStartedLoading: Page.frameStartedLoading_Handler;
    /** Fired when frame has stopped loading. */
    frameStoppedLoading: Page.frameStoppedLoading_Handler;
    /** Fired when frame schedules a potential navigation. */
    frameScheduledNavigation: Page.frameScheduledNavigation_Handler;
    /** Fired when frame no longer has a scheduled navigation. */
    frameClearedScheduledNavigation: Page.frameClearedScheduledNavigation_Handler;
    frameResized: Page.frameResized_Handler;
    /** Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) is about to open. */
    javascriptDialogOpening: Page.javascriptDialogOpening_Handler;
    /** Fired when a JavaScript initiated dialog (alert, confirm, prompt, or onbeforeunload) has been closed. */
    javascriptDialogClosed: Page.javascriptDialogClosed_Handler;
    /** Compressed image data requested by the <code>startScreencast</code>. */
    screencastFrame: Page.screencastFrame_Handler;
    /** Fired when the page with currently enabled screencast was shown or hidden </code>. */
    screencastVisibilityChanged: Page.screencastVisibilityChanged_Handler;
    /** Fired when a color has been picked. */
    colorPicked: Page.colorPicked_Handler;
    /** Fired when interstitial page was shown */
    interstitialShown: Page.interstitialShown_Handler;
    /** Fired when interstitial page was hidden */
    interstitialHidden: Page.interstitialHidden_Handler;
}
export declare namespace Page {
    /** Resource type as it was perceived by the rendering engine. */
    type ResourceType = "Document" | "Stylesheet" | "Image" | "Media" | "Font" | "Script" | "TextTrack" | "XHR" | "Fetch" | "EventSource" | "WebSocket" | "Manifest" | "Other";
    /** Unique frame identifier. */
    type FrameId = string;
    /** Information about the Frame on the page. */
    interface Frame {
        /** Frame unique identifier. */
        id: string;
        /** Parent frame identifier. */
        parentId?: string;
        /** Identifier of the loader associated with this frame. */
        loaderId: Network.LoaderId;
        /** Frame's name as specified in the tag. */
        name?: string;
        /** Frame document's URL. */
        url: string;
        /** Frame document's security origin. */
        securityOrigin: string;
        /** Frame document's mimeType as determined by the browser. */
        mimeType: string;
    }
    /** Information about the Frame hierarchy along with their cached resources. */
    interface FrameResourceTree {
        /** Frame information for this tree item. */
        frame: Frame;
        /** Child frames. */
        childFrames?: FrameResourceTree[];
        /** Information about frame resources. */
        resources: {
            url: string;
            type: ResourceType;
            mimeType: string;
            failed?: boolean;
            canceled?: boolean;
        }[];
    }
    /** Unique script identifier. */
    type ScriptIdentifier = string;
    /** Navigation history entry. */
    interface NavigationEntry {
        /** Unique id of the navigation history entry. */
        id: number;
        /** URL of the navigation history entry. */
        url: string;
        /** Title of the navigation history entry. */
        title: string;
    }
    /** Screencast frame metadata */
    interface ScreencastFrameMetadata {
        /** Top offset in DIP. */
        offsetTop: number;
        /** Page scale factor. */
        pageScaleFactor: number;
        /** Device screen width in DIP. */
        deviceWidth: number;
        /** Device screen height in DIP. */
        deviceHeight: number;
        /** Position of horizontal scroll in CSS pixels. */
        scrollOffsetX: number;
        /** Position of vertical scroll in CSS pixels. */
        scrollOffsetY: number;
        /** Frame swap timestamp. */
        timestamp?: number;
    }
    /** Javascript dialog type */
    type DialogType = "alert" | "confirm" | "prompt" | "beforeunload";
    type domContentEventFired_Parameters = {
        timestamp: number;
    };
    type domContentEventFired_Handler = (params: domContentEventFired_Parameters) => void;
    type loadEventFired_Parameters = {
        timestamp: number;
    };
    type loadEventFired_Handler = (params: loadEventFired_Parameters) => void;
    type frameAttached_Parameters = {
        /** Id of the frame that has been attached. */
        frameId: FrameId;
        /** Parent frame identifier. */
        parentFrameId: FrameId;
    };
    type frameAttached_Handler = (params: frameAttached_Parameters) => void;
    type frameNavigated_Parameters = {
        /** Frame object. */
        frame: Frame;
    };
    type frameNavigated_Handler = (params: frameNavigated_Parameters) => void;
    type frameDetached_Parameters = {
        /** Id of the frame that has been detached. */
        frameId: FrameId;
    };
    type frameDetached_Handler = (params: frameDetached_Parameters) => void;
    type frameStartedLoading_Parameters = {
        /** Id of the frame that has started loading. */
        frameId: FrameId;
    };
    type frameStartedLoading_Handler = (params: frameStartedLoading_Parameters) => void;
    type frameStoppedLoading_Parameters = {
        /** Id of the frame that has stopped loading. */
        frameId: FrameId;
    };
    type frameStoppedLoading_Handler = (params: frameStoppedLoading_Parameters) => void;
    type frameScheduledNavigation_Parameters = {
        /** Id of the frame that has scheduled a navigation. */
        frameId: FrameId;
        /** Delay (in seconds) until the navigation is scheduled to begin. The navigation is not guaranteed to start. */
        delay: number;
    };
    type frameScheduledNavigation_Handler = (params: frameScheduledNavigation_Parameters) => void;
    type frameClearedScheduledNavigation_Parameters = {
        /** Id of the frame that has cleared its scheduled navigation. */
        frameId: FrameId;
    };
    type frameClearedScheduledNavigation_Handler = (params: frameClearedScheduledNavigation_Parameters) => void;
    type frameResized_Handler = () => void;
    type javascriptDialogOpening_Parameters = {
        /** Message that will be displayed by the dialog. */
        message: string;
        /** Dialog type. */
        type: DialogType;
    };
    type javascriptDialogOpening_Handler = (params: javascriptDialogOpening_Parameters) => void;
    type javascriptDialogClosed_Parameters = {
        /** Whether dialog was confirmed. */
        result: boolean;
    };
    type javascriptDialogClosed_Handler = (params: javascriptDialogClosed_Parameters) => void;
    type screencastFrame_Parameters = {
        /** Base64-encoded compressed image. */
        data: string;
        /** Screencast frame metadata. */
        metadata: ScreencastFrameMetadata;
        /** Frame number. */
        sessionId: number;
    };
    type screencastFrame_Handler = (params: screencastFrame_Parameters) => void;
    type screencastVisibilityChanged_Parameters = {
        /** True if the page is visible. */
        visible: boolean;
    };
    type screencastVisibilityChanged_Handler = (params: screencastVisibilityChanged_Parameters) => void;
    type colorPicked_Parameters = {
        /** RGBA of the picked color. */
        color: DOM.RGBA;
    };
    type colorPicked_Handler = (params: colorPicked_Parameters) => void;
    type interstitialShown_Handler = () => void;
    type interstitialHidden_Handler = () => void;
    type addScriptToEvaluateOnLoad_Parameters = {
        scriptSource: string;
    };
    type addScriptToEvaluateOnLoad_Return = {
        /** Identifier of the added script. */
        identifier: ScriptIdentifier;
    };
    type removeScriptToEvaluateOnLoad_Parameters = {
        identifier: ScriptIdentifier;
    };
    type reload_Parameters = {
        /** If true, browser cache is ignored (as if the user pressed Shift+refresh). */
        ignoreCache?: boolean;
        /** If set, the script will be injected into all frames of the inspected page after reload. */
        scriptToEvaluateOnLoad?: string;
    };
    type navigate_Parameters = {
        /** URL to navigate the page to. */
        url: string;
    };
    type navigate_Return = {
        /** Frame id that will be navigated. */
        frameId: FrameId;
    };
    type getNavigationHistory_Parameters = any;
    type getNavigationHistory_Return = {
        /** Index of the current navigation history entry. */
        currentIndex: number;
        /** Array of navigation history entries. */
        entries: NavigationEntry[];
    };
    type navigateToHistoryEntry_Parameters = {
        /** Unique id of the entry to navigate to. */
        entryId: number;
    };
    type getCookies_Return = {
        /** Array of cookie objects. */
        cookies: Network.Cookie[];
    };
    type deleteCookie_Parameters = {
        /** Name of the cookie to remove. */
        cookieName: string;
        /** URL to match cooke domain and path. */
        url: string;
    };
    type getResourceTree_Return = {
        /** Present frame / resource tree structure. */
        frameTree: FrameResourceTree;
    };
    type getResourceContent_Parameters = {
        /** Frame id to get resource for. */
        frameId: FrameId;
        /** URL of the resource to get content for. */
        url: string;
    };
    type getResourceContent_Return = {
        /** Resource content. */
        content: string;
        /** True, if content was served as base64. */
        base64Encoded: boolean;
    };
    type searchInResource_Parameters = {
        /** Frame id for resource to search in. */
        frameId: FrameId;
        /** URL of the resource to search in. */
        url: string;
        /** String to search for. */
        query: string;
        /** If true, search is case sensitive. */
        caseSensitive?: boolean;
        /** If true, treats string parameter as regex. */
        isRegex?: boolean;
    };
    type searchInResource_Return = {
        /** List of search matches. */
        result: Debugger.SearchMatch[];
    };
    type setDocumentContent_Parameters = {
        /** Frame id to set HTML for. */
        frameId: FrameId;
        /** HTML content to set. */
        html: string;
    };
    type setDeviceMetricsOverride_Parameters = {
        /** Overriding width value in pixels (minimum 0, maximum 10000000). 0 disables the override. */
        width: number;
        /** Overriding height value in pixels (minimum 0, maximum 10000000). 0 disables the override. */
        height: number;
        /** Overriding device scale factor value. 0 disables the override. */
        deviceScaleFactor: number;
        /** Whether to emulate mobile device. This includes viewport meta tag, overlay scrollbars, text autosizing and more. */
        mobile: boolean;
        /** Whether a view that exceeds the available browser window area should be scaled down to fit. */
        fitWindow: boolean;
        /** Scale to apply to resulting view image. Ignored in |fitWindow| mode. */
        scale?: number;
        /** X offset to shift resulting view image by. Ignored in |fitWindow| mode. */
        offsetX?: number;
        /** Y offset to shift resulting view image by. Ignored in |fitWindow| mode. */
        offsetY?: number;
        /** Overriding screen width value in pixels (minimum 0, maximum 10000000). Only used for |mobile==true|. */
        screenWidth?: number;
        /** Overriding screen height value in pixels (minimum 0, maximum 10000000). Only used for |mobile==true|. */
        screenHeight?: number;
        /** Overriding view X position on screen in pixels (minimum 0, maximum 10000000). Only used for |mobile==true|. */
        positionX?: number;
        /** Overriding view Y position on screen in pixels (minimum 0, maximum 10000000). Only used for |mobile==true|. */
        positionY?: number;
    };
    type setGeolocationOverride_Parameters = {
        /** Mock latitude */
        latitude?: number;
        /** Mock longitude */
        longitude?: number;
        /** Mock accuracy */
        accuracy?: number;
    };
    type setDeviceOrientationOverride_Parameters = {
        /** Mock alpha */
        alpha: number;
        /** Mock beta */
        beta: number;
        /** Mock gamma */
        gamma: number;
    };
    type setTouchEmulationEnabled_Parameters = {
        /** Whether the touch event emulation should be enabled. */
        enabled: boolean;
        /** Touch/gesture events configuration. Default: current platform. */
        configuration?: "mobile" | "desktop";
    };
    type captureScreenshot_Parameters = any;
    type captureScreenshot_Return = {
        /** Base64-encoded image data (PNG). */
        data: string;
    };
    type startScreencast_Parameters = {
        /** Image compression format. */
        format?: "jpeg" | "png";
        /** Compression quality from range [0..100]. */
        quality?: number;
        /** Maximum screenshot width. */
        maxWidth?: number;
        /** Maximum screenshot height. */
        maxHeight?: number;
        /** Send every n-th frame. */
        everyNthFrame?: number;
    };
    type screencastFrameAck_Parameters = {
        /** Frame number. */
        sessionId: number;
    };
    type handleJavaScriptDialog_Parameters = {
        /** Whether to accept or dismiss the dialog. */
        accept: boolean;
        /** The text to enter into the dialog prompt before accepting. Used only if this is a prompt dialog. */
        promptText?: string;
    };
    type setColorPickerEnabled_Parameters = {
        /** Shows / hides color picker */
        enabled: boolean;
    };
    type setOverlayMessage_Parameters = {
        /** Overlay message to display when paused in debugger. */
        message?: string;
    };
}
/** This domain allows to control rendering of the page. */
export declare class Rendering {
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Requests that backend shows paint rectangles */
    setShowPaintRects(params: Rendering.setShowPaintRects_Parameters): Promise<void>;
    /** Requests that backend shows debug borders on layers */
    setShowDebugBorders(params: Rendering.setShowDebugBorders_Parameters): Promise<void>;
    /** Requests that backend shows the FPS counter */
    setShowFPSCounter(params: Rendering.setShowFPSCounter_Parameters): Promise<void>;
    /** Requests that backend shows scroll bottleneck rects */
    setShowScrollBottleneckRects(params: Rendering.setShowScrollBottleneckRects_Parameters): Promise<void>;
}
export declare namespace Rendering {
    type setShowPaintRects_Parameters = {
        /** True for showing paint rectangles */
        result: boolean;
    };
    type setShowDebugBorders_Parameters = {
        /** True for showing debug borders */
        show: boolean;
    };
    type setShowFPSCounter_Parameters = {
        /** True for showing the FPS counter */
        show: boolean;
    };
    type setShowScrollBottleneckRects_Parameters = {
        /** True for showing scroll bottleneck rects */
        show: boolean;
    };
}
/** This domain emulates different environments for the page. */
export declare class Emulation {
    private _viewportChanged;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Overrides the values of device screen dimensions (window.screen.width, window.screen.height, window.innerWidth, window.innerHeight, and "device-width"/"device-height"-related CSS media query results). */
    setDeviceMetricsOverride(params: Emulation.setDeviceMetricsOverride_Parameters): Promise<void>;
    /** Clears the overriden device metrics. */
    clearDeviceMetricsOverride(): Promise<void>;
    /** Requests that scroll offsets and page scale factor are reset to initial values. */
    resetScrollAndPageScaleFactor(): Promise<void>;
    /** Sets a specified page scale factor. */
    setPageScaleFactor(params: Emulation.setPageScaleFactor_Parameters): Promise<void>;
    /** Switches script execution in the page. */
    setScriptExecutionDisabled(params: Emulation.setScriptExecutionDisabled_Parameters): Promise<void>;
    /** Overrides the Geolocation Position or Error. Omitting any of the parameters emulates position unavailable. */
    setGeolocationOverride(params: Emulation.setGeolocationOverride_Parameters): Promise<void>;
    /** Clears the overriden Geolocation Position and Error. */
    clearGeolocationOverride(): Promise<void>;
    /** Toggles mouse event-based touch event emulation. */
    setTouchEmulationEnabled(params: Emulation.setTouchEmulationEnabled_Parameters): Promise<void>;
    /** Emulates the given media for CSS media queries. */
    setEmulatedMedia(params: Emulation.setEmulatedMedia_Parameters): Promise<void>;
    /** Enables CPU throttling to emulate slow CPUs. */
    setCPUThrottlingRate(params: Emulation.setCPUThrottlingRate_Parameters): Promise<void>;
    /** Tells whether emulation is supported. */
    canEmulate(): Promise<Emulation.canEmulate_Return>;
    /** Fired when a visible page viewport has changed. Only fired when device metrics are overridden. */
    viewportChanged: Emulation.viewportChanged_Handler;
}
export declare namespace Emulation {
    /** Visible page viewport */
    interface Viewport {
        /** X scroll offset in CSS pixels. */
        scrollX: number;
        /** Y scroll offset in CSS pixels. */
        scrollY: number;
        /** Contents width in CSS pixels. */
        contentsWidth: number;
        /** Contents height in CSS pixels. */
        contentsHeight: number;
        /** Page scale factor. */
        pageScaleFactor: number;
        /** Minimum page scale factor. */
        minimumPageScaleFactor: number;
        /** Maximum page scale factor. */
        maximumPageScaleFactor: number;
    }
    type viewportChanged_Parameters = {
        /** Viewport description. */
        viewport: Viewport;
    };
    type viewportChanged_Handler = (params: viewportChanged_Parameters) => void;
    type setDeviceMetricsOverride_Parameters = {
        /** Overriding width value in pixels (minimum 0, maximum 10000000). 0 disables the override. */
        width: number;
        /** Overriding height value in pixels (minimum 0, maximum 10000000). 0 disables the override. */
        height: number;
        /** Overriding device scale factor value. 0 disables the override. */
        deviceScaleFactor: number;
        /** Whether to emulate mobile device. This includes viewport meta tag, overlay scrollbars, text autosizing and more. */
        mobile: boolean;
        /** Whether a view that exceeds the available browser window area should be scaled down to fit. */
        fitWindow: boolean;
        /** Scale to apply to resulting view image. Ignored in |fitWindow| mode. */
        scale?: number;
        /** X offset to shift resulting view image by. Ignored in |fitWindow| mode. */
        offsetX?: number;
        /** Y offset to shift resulting view image by. Ignored in |fitWindow| mode. */
        offsetY?: number;
        /** Overriding screen width value in pixels (minimum 0, maximum 10000000). Only used for |mobile==true|. */
        screenWidth?: number;
        /** Overriding screen height value in pixels (minimum 0, maximum 10000000). Only used for |mobile==true|. */
        screenHeight?: number;
        /** Overriding view X position on screen in pixels (minimum 0, maximum 10000000). Only used for |mobile==true|. */
        positionX?: number;
        /** Overriding view Y position on screen in pixels (minimum 0, maximum 10000000). Only used for |mobile==true|. */
        positionY?: number;
    };
    type setPageScaleFactor_Parameters = {
        /** Page scale factor. */
        pageScaleFactor: number;
    };
    type setScriptExecutionDisabled_Parameters = {
        /** Whether script execution should be disabled in the page. */
        value: boolean;
    };
    type setGeolocationOverride_Parameters = {
        /** Mock latitude */
        latitude?: number;
        /** Mock longitude */
        longitude?: number;
        /** Mock accuracy */
        accuracy?: number;
    };
    type setTouchEmulationEnabled_Parameters = {
        /** Whether the touch event emulation should be enabled. */
        enabled: boolean;
        /** Touch/gesture events configuration. Default: current platform. */
        configuration?: "mobile" | "desktop";
    };
    type setEmulatedMedia_Parameters = {
        /** Media type to emulate. Empty string disables the override. */
        media: string;
    };
    type setCPUThrottlingRate_Parameters = {
        /** Throttling rate as a slowdown factor (1 is no throttle, 2 is 2x slowdown, etc). */
        rate: number;
    };
    type canEmulate_Return = {
        /** True if emulation is supported. */
        result: boolean;
    };
}
/** Runtime domain exposes JavaScript runtime by means of remote evaluation and mirror objects. Evaluation results are returned as mirror object that expose object type, string representation and unique identifier that can be used for further object reference. Original objects are maintained in memory unless they are either explicitly released or are released along with the other objects in their object group. */
export declare class Runtime {
    private _executionContextCreated;
    private _executionContextDestroyed;
    private _executionContextsCleared;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Evaluates expression on global object. */
    evaluate(params: Runtime.evaluate_Parameters): Promise<Runtime.evaluate_Return>;
    /** Calls function with given declaration on the given object. Object group of the result is inherited from the target object. */
    callFunctionOn(params: Runtime.callFunctionOn_Parameters): Promise<Runtime.callFunctionOn_Return>;
    /** Returns properties of a given object. Object group of the result is inherited from the target object. */
    getProperties(params: Runtime.getProperties_Parameters): Promise<Runtime.getProperties_Return>;
    /** Releases remote object with given id. */
    releaseObject(params: Runtime.releaseObject_Parameters): Promise<void>;
    /** Releases all remote objects that belong to a given group. */
    releaseObjectGroup(params: Runtime.releaseObjectGroup_Parameters): Promise<void>;
    /** Tells inspected instance(worker or page) that it can run in case it was started paused. */
    run(): Promise<void>;
    /** Enables reporting of execution contexts creation by means of <code>executionContextCreated</code> event. When the reporting gets enabled the event will be sent immediately for each existing execution context. */
    enable(): Promise<void>;
    /** Disables reporting of execution contexts creation. */
    disable(): Promise<void>;
    isRunRequired(): Promise<Runtime.isRunRequired_Return>;
    setCustomObjectFormatterEnabled(params: Runtime.setCustomObjectFormatterEnabled_Parameters): Promise<void>;
    /** Issued when new execution context is created. */
    executionContextCreated: Runtime.executionContextCreated_Handler;
    /** Issued when execution context is destroyed. */
    executionContextDestroyed: Runtime.executionContextDestroyed_Handler;
    /** Issued when all executionContexts were cleared in browser */
    executionContextsCleared: Runtime.executionContextsCleared_Handler;
}
export declare namespace Runtime {
    /** Unique object identifier. */
    type RemoteObjectId = string;
    /** Mirror object referencing original JavaScript object. */
    interface RemoteObject {
        /** Object type. */
        type: "object" | "function" | "undefined" | "string" | "number" | "boolean" | "symbol";
        /** Object subtype hint. Specified for <code>object</code> type values only. */
        subtype?: "array" | "null" | "node" | "regexp" | "date" | "map" | "set" | "iterator" | "generator" | "error";
        /** Object class (constructor) name. Specified for <code>object</code> type values only. */
        className?: string;
        /** Remote object value in case of primitive values or JSON values (if it was requested), or description string if the value can not be JSON-stringified (like NaN, Infinity, -Infinity, -0). */
        value?: any;
        /** String representation of the object. */
        description?: string;
        /** Unique object identifier (for non-primitive values). */
        objectId?: RemoteObjectId;
        /** Preview containing abbreviated property values. Specified for <code>object</code> type values only. */
        preview?: ObjectPreview;
        customPreview?: CustomPreview;
    }
    interface CustomPreview {
        header: string;
        hasBody: boolean;
        formatterObjectId: RemoteObjectId;
        configObjectId?: RemoteObjectId;
    }
    /** Object containing abbreviated remote object value. */
    interface ObjectPreview {
        /** Object type. */
        type: "object" | "function" | "undefined" | "string" | "number" | "boolean" | "symbol";
        /** Object subtype hint. Specified for <code>object</code> type values only. */
        subtype?: "array" | "null" | "node" | "regexp" | "date" | "map" | "set" | "iterator" | "generator" | "error";
        /** String representation of the object. */
        description?: string;
        /** Determines whether preview is lossless (contains all information of the original object). */
        lossless: boolean;
        /** True iff some of the properties or entries of the original object did not fit. */
        overflow: boolean;
        /** List of the properties. */
        properties: PropertyPreview[];
        /** List of the entries. Specified for <code>map</code> and <code>set</code> subtype values only. */
        entries?: EntryPreview[];
    }
    interface PropertyPreview {
        /** Property name. */
        name: string;
        /** Object type. Accessor means that the property itself is an accessor property. */
        type: "object" | "function" | "undefined" | "string" | "number" | "boolean" | "symbol" | "accessor";
        /** User-friendly property value string. */
        value?: string;
        /** Nested value preview. */
        valuePreview?: ObjectPreview;
        /** Object subtype hint. Specified for <code>object</code> type values only. */
        subtype?: "array" | "null" | "node" | "regexp" | "date" | "map" | "set" | "iterator" | "generator" | "error";
    }
    interface EntryPreview {
        /** Preview of the key. Specified for map-like collection entries. */
        key?: ObjectPreview;
        /** Preview of the value. */
        value: ObjectPreview;
    }
    /** Object property descriptor. */
    interface PropertyDescriptor {
        /** Property name or symbol description. */
        name: string;
        /** The value associated with the property. */
        value?: RemoteObject;
        /** True if the value associated with the property may be changed (data descriptors only). */
        writable?: boolean;
        /** A function which serves as a getter for the property, or <code>undefined</code> if there is no getter (accessor descriptors only). */
        get?: RemoteObject;
        /** A function which serves as a setter for the property, or <code>undefined</code> if there is no setter (accessor descriptors only). */
        set?: RemoteObject;
        /** True if the type of this property descriptor may be changed and if the property may be deleted from the corresponding object. */
        configurable: boolean;
        /** True if this property shows up during enumeration of the properties on the corresponding object. */
        enumerable: boolean;
        /** True if the result was thrown during the evaluation. */
        wasThrown?: boolean;
        /** True if the property is owned for the object. */
        isOwn?: boolean;
        /** Property symbol object, if the property is of the <code>symbol</code> type. */
        symbol?: RemoteObject;
    }
    /** Object internal property descriptor. This property isn't normally visible in JavaScript code. */
    interface InternalPropertyDescriptor {
        /** Conventional property name. */
        name: string;
        /** The value associated with the property. */
        value?: RemoteObject;
    }
    /** Represents function call argument. Either remote object id <code>objectId</code> or primitive <code>value</code> or neither of (for undefined) them should be specified. */
    interface CallArgument {
        /** Primitive value, or description string if the value can not be JSON-stringified (like NaN, Infinity, -Infinity, -0). */
        value?: any;
        /** Remote object handle. */
        objectId?: RemoteObjectId;
        /** Object type. */
        type?: "object" | "function" | "undefined" | "string" | "number" | "boolean" | "symbol";
    }
    /** Id of an execution context. */
    type ExecutionContextId = number;
    /** Description of an isolated world. */
    interface ExecutionContextDescription {
        /** Unique id of the execution context. It can be used to specify in which execution context script evaluation should be performed. */
        id: ExecutionContextId;
        /** Context type. It is used e.g. to distinguish content scripts from web page script. */
        type?: string;
        /** Execution context origin. */
        origin: string;
        /** Human readable name describing given context. */
        name: string;
        /** Id of the owning frame. May be an empty string if the context is not associated with a frame. */
        frameId: string;
    }
    type executionContextCreated_Parameters = {
        /** A newly created execution contex. */
        context: ExecutionContextDescription;
    };
    type executionContextCreated_Handler = (params: executionContextCreated_Parameters) => void;
    type executionContextDestroyed_Parameters = {
        /** Id of the destroyed context */
        executionContextId: ExecutionContextId;
    };
    type executionContextDestroyed_Handler = (params: executionContextDestroyed_Parameters) => void;
    type executionContextsCleared_Handler = () => void;
    type evaluate_Parameters = {
        /** Expression to evaluate. */
        expression: string;
        /** Symbolic group name that can be used to release multiple objects. */
        objectGroup?: string;
        /** Determines whether Command Line API should be available during the evaluation. */
        includeCommandLineAPI?: boolean;
        /** Specifies whether evaluation should stop on exceptions and mute console. Overrides setPauseOnException state. */
        doNotPauseOnExceptionsAndMuteConsole?: boolean;
        /** Specifies in which isolated context to perform evaluation. Each content script lives in an isolated context and this parameter may be used to specify one of those contexts. If the parameter is omitted or 0 the evaluation will be performed in the context of the inspected page. */
        contextId?: ExecutionContextId;
        /** Whether the result is expected to be a JSON object that should be sent by value. */
        returnByValue?: boolean;
        /** Whether preview should be generated for the result. */
        generatePreview?: boolean;
    };
    type evaluate_Return = {
        /** Evaluation result. */
        result: RemoteObject;
        /** True if the result was thrown during the evaluation. */
        wasThrown?: boolean;
        /** Exception details. */
        exceptionDetails?: Debugger.ExceptionDetails;
    };
    type callFunctionOn_Parameters = {
        /** Identifier of the object to call function on. */
        objectId: RemoteObjectId;
        /** Declaration of the function to call. */
        functionDeclaration: string;
        /** Call arguments. All call arguments must belong to the same JavaScript world as the target object. */
        arguments?: CallArgument[];
        /** Specifies whether function call should stop on exceptions and mute console. Overrides setPauseOnException state. */
        doNotPauseOnExceptionsAndMuteConsole?: boolean;
        /** Whether the result is expected to be a JSON object which should be sent by value. */
        returnByValue?: boolean;
        /** Whether preview should be generated for the result. */
        generatePreview?: boolean;
    };
    type callFunctionOn_Return = {
        /** Call result. */
        result: RemoteObject;
        /** True if the result was thrown during the evaluation. */
        wasThrown?: boolean;
    };
    type getProperties_Parameters = {
        /** Identifier of the object to return properties for. */
        objectId: RemoteObjectId;
        /** If true, returns properties belonging only to the element itself, not to its prototype chain. */
        ownProperties?: boolean;
        /** If true, returns accessor properties (with getter/setter) only; internal properties are not returned either. */
        accessorPropertiesOnly?: boolean;
        /** Whether preview should be generated for the results. */
        generatePreview?: boolean;
    };
    type getProperties_Return = {
        /** Object properties. */
        result: PropertyDescriptor[];
        /** Internal object properties (only of the element itself). */
        internalProperties?: InternalPropertyDescriptor[];
        /** Exception details. */
        exceptionDetails?: Debugger.ExceptionDetails;
    };
    type releaseObject_Parameters = {
        /** Identifier of the object to release. */
        objectId: RemoteObjectId;
    };
    type releaseObjectGroup_Parameters = {
        /** Symbolic object group name. */
        objectGroup: string;
    };
    type isRunRequired_Return = {
        /** True if the Runtime is in paused on start state. */
        result: boolean;
    };
    type setCustomObjectFormatterEnabled_Parameters = {
        enabled: boolean;
    };
}
/** Console domain defines methods and events for interaction with the JavaScript console. Console collects messages created by means of the <a href='http://getfirebug.com/wiki/index.php/Console_API'>JavaScript Console API</a>. One needs to enable this domain using <code>enable</code> command in order to start receiving the console messages. Browser collects messages issued while console domain is not enabled as well and reports them using <code>messageAdded</code> notification upon enabling. */
export declare class Console {
    private _messageAdded;
    private _messageRepeatCountUpdated;
    private _messagesCleared;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Enables console domain, sends the messages collected so far to the client by means of the <code>messageAdded</code> notification. */
    enable(): Promise<void>;
    /** Disables console domain, prevents further console messages from being reported to the client. */
    disable(): Promise<void>;
    /** Clears console messages collected in the browser. */
    clearMessages(): Promise<void>;
    /** Issued when new console message is added. */
    messageAdded: Console.messageAdded_Handler;
    /** Is not issued. Will be gone in the future versions of the protocol. */
    messageRepeatCountUpdated: Console.messageRepeatCountUpdated_Handler;
    /** Issued when console is cleared. This happens either upon <code>clearMessages</code> command or after page navigation. */
    messagesCleared: Console.messagesCleared_Handler;
}
export declare namespace Console {
    /** Number of seconds since epoch. */
    type Timestamp = number;
    /** Console message. */
    interface ConsoleMessage {
        /** Message source. */
        source: "xml" | "javascript" | "network" | "console-api" | "storage" | "appcache" | "rendering" | "security" | "other" | "deprecation";
        /** Message severity. */
        level: "log" | "warning" | "error" | "debug" | "info" | "revokedError";
        /** Message text. */
        text: string;
        /** Console message type. */
        type?: "log" | "dir" | "dirxml" | "table" | "trace" | "clear" | "startGroup" | "startGroupCollapsed" | "endGroup" | "assert" | "profile" | "profileEnd";
        /** Script ID of the message origin. */
        scriptId?: string;
        /** URL of the message origin. */
        url?: string;
        /** Line number in the resource that generated this message. */
        line?: number;
        /** Column number in the resource that generated this message. */
        column?: number;
        /** Repeat count for repeated messages. */
        repeatCount?: number;
        /** Message parameters in case of the formatted message. */
        parameters?: Runtime.RemoteObject[];
        /** JavaScript stack trace for assertions and error messages. */
        stackTrace?: StackTrace;
        /** Asynchronous JavaScript stack trace that preceded this message, if available. */
        asyncStackTrace?: AsyncStackTrace;
        /** Identifier of the network request associated with this message. */
        networkRequestId?: Network.RequestId;
        /** Timestamp, when this message was fired. */
        timestamp: Timestamp;
        /** Identifier of the context where this message was created */
        executionContextId?: Runtime.ExecutionContextId;
        /** Message id. */
        messageId?: number;
        /** Related message id. */
        relatedMessageId?: number;
    }
    /** Stack entry for console errors and assertions. */
    interface CallFrame {
        /** JavaScript function name. */
        functionName: string;
        /** JavaScript script id. */
        scriptId: string;
        /** JavaScript script name or url. */
        url: string;
        /** JavaScript script line number. */
        lineNumber: number;
        /** JavaScript script column number. */
        columnNumber: number;
    }
    /** Call frames for assertions or error messages. */
    type StackTrace = CallFrame[];
    /** Asynchronous JavaScript call stack. */
    interface AsyncStackTrace {
        /** Call frames of the stack trace. */
        callFrames: CallFrame[];
        /** String label of this stack trace. For async traces this may be a name of the function that initiated the async call. */
        description?: string;
        /** Next asynchronous stack trace, if any. */
        asyncStackTrace?: AsyncStackTrace;
    }
    type messageAdded_Parameters = {
        /** Console message that has been added. */
        message: ConsoleMessage;
    };
    type messageAdded_Handler = (params: messageAdded_Parameters) => void;
    type messageRepeatCountUpdated_Parameters = {
        /** New repeat count value. */
        count: number;
        /** Timestamp of most recent message in batch. */
        timestamp: Timestamp;
    };
    type messageRepeatCountUpdated_Handler = (params: messageRepeatCountUpdated_Parameters) => void;
    type messagesCleared_Handler = () => void;
}
/** Security */
export declare class Security {
    private _securityStateChanged;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Enables tracking security state changes. */
    enable(): Promise<void>;
    /** Disables tracking security state changes. */
    disable(): Promise<void>;
    /** The security state of the page changed. */
    securityStateChanged: Security.securityStateChanged_Handler;
}
export declare namespace Security {
    /** The security level of a page or resource. */
    type SecurityState = "unknown" | "neutral" | "insecure" | "warning" | "secure" | "info";
    /** An explanation of an factor contributing to the security state. */
    interface SecurityStateExplanation {
        /** Security state representing the severity of the factor being explained. */
        securityState: SecurityState;
        /** Short phrase describing the type of factor. */
        summary: string;
        /** Full text explanation of the factor. */
        description: string;
        /** Associated certificate id. */
        certificateId?: Network.CertificateId;
    }
    /** Information about mixed content on the page. */
    interface MixedContentStatus {
        /** True if the page ran insecure content such as scripts. */
        ranInsecureContent: boolean;
        /** True if the page displayed insecure content such as images. */
        displayedInsecureContent: boolean;
        /** Security state representing a page that ran insecure content. */
        ranInsecureContentStyle: SecurityState;
        /** Security state representing a page that displayed insecure content. */
        displayedInsecureContentStyle: SecurityState;
    }
    type securityStateChanged_Parameters = {
        /** Security state. */
        securityState: SecurityState;
        /** List of explanations for the security state. If the overall security state is `insecure` or `warning`, at least one corresponding explanation should be included. */
        explanations?: SecurityStateExplanation[];
        /** Information about mixed content on the page. */
        mixedContentStatus?: MixedContentStatus;
        /** True if the page was loaded over cryptographic transport such as HTTPS. */
        schemeIsCryptographic?: boolean;
    };
    type securityStateChanged_Handler = (params: securityStateChanged_Parameters) => void;
}
/** Network domain allows tracking network activities of the page. It exposes information about http, file, data and other requests and responses, their headers, bodies, timing, etc. */
export declare class Network {
    private _requestWillBeSent;
    private _requestServedFromCache;
    private _responseReceived;
    private _dataReceived;
    private _loadingFinished;
    private _loadingFailed;
    private _webSocketWillSendHandshakeRequest;
    private _webSocketHandshakeResponseReceived;
    private _webSocketCreated;
    private _webSocketClosed;
    private _webSocketFrameReceived;
    private _webSocketFrameError;
    private _webSocketFrameSent;
    private _eventSourceMessageReceived;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Enables network tracking, network events will now be delivered to the client. */
    enable(): Promise<void>;
    /** Disables network tracking, prevents network events from being sent to the client. */
    disable(): Promise<void>;
    /** Allows overriding user agent with the given string. */
    setUserAgentOverride(params: Network.setUserAgentOverride_Parameters): Promise<void>;
    /** Specifies whether to always send extra HTTP headers with the requests from this page. */
    setExtraHTTPHeaders(params: Network.setExtraHTTPHeaders_Parameters): Promise<void>;
    /** Returns content served for the given request. */
    getResponseBody(params: Network.getResponseBody_Parameters): Promise<Network.getResponseBody_Return>;
    /** Blocks specific URL from loading. */
    addBlockedURL(params: Network.addBlockedURL_Parameters): Promise<void>;
    /** Cancels blocking of a specific URL from loading. */
    removeBlockedURL(params: Network.removeBlockedURL_Parameters): Promise<void>;
    /** This method sends a new XMLHttpRequest which is identical to the original one. The following parameters should be identical: method, url, async, request body, extra headers, withCredentials attribute, user, password. */
    replayXHR(params: Network.replayXHR_Parameters): Promise<void>;
    /** Toggles monitoring of XMLHttpRequest. If <code>true</code>, console will receive messages upon each XHR issued. */
    setMonitoringXHREnabled(params: Network.setMonitoringXHREnabled_Parameters): Promise<void>;
    /** Tells whether clearing browser cache is supported. */
    canClearBrowserCache(): Promise<Network.canClearBrowserCache_Return>;
    /** Clears browser cache. */
    clearBrowserCache(): Promise<void>;
    /** Tells whether clearing browser cookies is supported. */
    canClearBrowserCookies(): Promise<Network.canClearBrowserCookies_Return>;
    /** Clears browser cookies. */
    clearBrowserCookies(): Promise<void>;
    /** Returns all browser cookies. Depending on the backend support, will return detailed cookie information in the <code>cookies</code> field. */
    getCookies(): Promise<Network.getCookies_Return>;
    /** Deletes browser cookie with given name, domain and path. */
    deleteCookie(params: Network.deleteCookie_Parameters): Promise<void>;
    /** Tells whether emulation of network conditions is supported. */
    canEmulateNetworkConditions(): Promise<Network.canEmulateNetworkConditions_Return>;
    /** Activates emulation of network conditions. */
    emulateNetworkConditions(params: Network.emulateNetworkConditions_Parameters): Promise<void>;
    /** Toggles ignoring cache for each request. If <code>true</code>, cache will not be used. */
    setCacheDisabled(params: Network.setCacheDisabled_Parameters): Promise<void>;
    /** For testing. */
    setDataSizeLimitsForTest(params: Network.setDataSizeLimitsForTest_Parameters): Promise<void>;
    /** Returns details for the given certificate. */
    getCertificateDetails(params: Network.getCertificateDetails_Parameters): Promise<Network.getCertificateDetails_Return>;
    /** Displays native dialog with the certificate details. */
    showCertificateViewer(params: Network.showCertificateViewer_Parameters): Promise<void>;
    /** Fired when page is about to send HTTP request. */
    requestWillBeSent: Network.requestWillBeSent_Handler;
    /** Fired if request ended up loading from cache. */
    requestServedFromCache: Network.requestServedFromCache_Handler;
    /** Fired when HTTP response is available. */
    responseReceived: Network.responseReceived_Handler;
    /** Fired when data chunk was received over the network. */
    dataReceived: Network.dataReceived_Handler;
    /** Fired when HTTP request has finished loading. */
    loadingFinished: Network.loadingFinished_Handler;
    /** Fired when HTTP request has failed to load. */
    loadingFailed: Network.loadingFailed_Handler;
    /** Fired when WebSocket is about to initiate handshake. */
    webSocketWillSendHandshakeRequest: Network.webSocketWillSendHandshakeRequest_Handler;
    /** Fired when WebSocket handshake response becomes available. */
    webSocketHandshakeResponseReceived: Network.webSocketHandshakeResponseReceived_Handler;
    /** Fired upon WebSocket creation. */
    webSocketCreated: Network.webSocketCreated_Handler;
    /** Fired when WebSocket is closed. */
    webSocketClosed: Network.webSocketClosed_Handler;
    /** Fired when WebSocket frame is received. */
    webSocketFrameReceived: Network.webSocketFrameReceived_Handler;
    /** Fired when WebSocket frame error occurs. */
    webSocketFrameError: Network.webSocketFrameError_Handler;
    /** Fired when WebSocket frame is sent. */
    webSocketFrameSent: Network.webSocketFrameSent_Handler;
    /** Fired when EventSource message is received. */
    eventSourceMessageReceived: Network.eventSourceMessageReceived_Handler;
}
export declare namespace Network {
    /** Unique loader identifier. */
    type LoaderId = string;
    /** Unique request identifier. */
    type RequestId = string;
    /** Number of seconds since epoch. */
    type Timestamp = number;
    /** Request / response headers as keys / values of JSON object. */
    type Headers = any;
    /** Timing information for the request. */
    interface ResourceTiming {
        /** Timing's requestTime is a baseline in seconds, while the other numbers are ticks in milliseconds relatively to this requestTime. */
        requestTime: number;
        /** Started resolving proxy. */
        proxyStart: number;
        /** Finished resolving proxy. */
        proxyEnd: number;
        /** Started DNS address resolve. */
        dnsStart: number;
        /** Finished DNS address resolve. */
        dnsEnd: number;
        /** Started connecting to the remote host. */
        connectStart: number;
        /** Connected to the remote host. */
        connectEnd: number;
        /** Started SSL handshake. */
        sslStart: number;
        /** Finished SSL handshake. */
        sslEnd: number;
        /** Started running ServiceWorker. */
        workerStart: number;
        /** Finished Starting ServiceWorker. */
        workerReady: number;
        /** Started sending request. */
        sendStart: number;
        /** Finished sending request. */
        sendEnd: number;
        /** Finished receiving response headers. */
        receiveHeadersEnd: number;
    }
    /** Loading priority of a resource request. */
    type ResourcePriority = "VeryLow" | "Low" | "Medium" | "High" | "VeryHigh";
    /** HTTP request data. */
    interface Request {
        /** Request URL. */
        url: string;
        /** HTTP request method. */
        method: string;
        /** HTTP request headers. */
        headers: Headers;
        /** HTTP POST request data. */
        postData?: string;
        /** The mixed content status of the request, as defined in http://www.w3.org/TR/mixed-content/ */
        mixedContentType?: "blockable" | "optionally-blockable" | "none";
        /** Priority of the resource request at the time request is sent. */
        initialPriority: ResourcePriority;
    }
    /** An internal certificate ID value. */
    type CertificateId = number;
    /** Subject of a certificate. */
    interface CertificateSubject {
        /** Certificate subject name. */
        name: string;
        /** Subject Alternative Name (SAN) DNS names. */
        sanDnsNames: string[];
        /** Subject Alternative Name (SAN) IP addresses. */
        sanIpAddresses: string[];
    }
    /** Details about a request's certificate. */
    interface CertificateDetails {
        /** Certificate subject. */
        subject: CertificateSubject;
        /** Name of the issuing CA. */
        issuer: string;
        /** Certificate valid from date. */
        validFrom: Timestamp;
        /** Certificate valid to (expiration) date */
        validTo: Timestamp;
    }
    /** Security details about a request. */
    interface SecurityDetails {
        /** Protocol name (e.g. "TLS 1.2" or "QUIC"). */
        protocol: string;
        /** Key Exchange used by the connection. */
        keyExchange: string;
        /** Cipher name. */
        cipher: string;
        /** TLS MAC. Note that AEAD ciphers do not have separate MACs. */
        mac?: string;
        /** Certificate ID value. */
        certificateId: CertificateId;
    }
    /** The reason why request was blocked. */
    type BlockedReason = "csp" | "mixed-content" | "origin" | "inspector" | "other";
    /** HTTP response data. */
    interface Response {
        /** Response URL. This URL can be different from CachedResource.url in case of redirect. */
        url: string;
        /** HTTP response status code. */
        status: number;
        /** HTTP response status text. */
        statusText: string;
        /** HTTP response headers. */
        headers: Headers;
        /** HTTP response headers text. */
        headersText?: string;
        /** Resource mimeType as determined by the browser. */
        mimeType: string;
        /** Refined HTTP request headers that were actually transmitted over the network. */
        requestHeaders?: Headers;
        /** HTTP request headers text. */
        requestHeadersText?: string;
        /** Specifies whether physical connection was actually reused for this request. */
        connectionReused: boolean;
        /** Physical connection id that was actually used for this request. */
        connectionId: number;
        /** Remote IP address. */
        remoteIPAddress?: string;
        /** Remote port. */
        remotePort?: number;
        /** Specifies that the request was served from the disk cache. */
        fromDiskCache?: boolean;
        /** Specifies that the request was served from the ServiceWorker. */
        fromServiceWorker?: boolean;
        /** Total number of bytes received for this request so far. */
        encodedDataLength: number;
        /** Timing information for the given request. */
        timing?: ResourceTiming;
        /** Protocol used to fetch this request. */
        protocol?: string;
        /** Security state of the request resource. */
        securityState: Security.SecurityState;
        /** Security details for the request. */
        securityDetails?: SecurityDetails;
    }
    /** WebSocket request data. */
    interface WebSocketRequest {
        /** HTTP request headers. */
        headers: Headers;
    }
    /** WebSocket response data. */
    interface WebSocketResponse {
        /** HTTP response status code. */
        status: number;
        /** HTTP response status text. */
        statusText: string;
        /** HTTP response headers. */
        headers: Headers;
        /** HTTP response headers text. */
        headersText?: string;
        /** HTTP request headers. */
        requestHeaders?: Headers;
        /** HTTP request headers text. */
        requestHeadersText?: string;
    }
    /** WebSocket frame data. */
    interface WebSocketFrame {
        /** WebSocket frame opcode. */
        opcode: number;
        /** WebSocke frame mask. */
        mask: boolean;
        /** WebSocke frame payload data. */
        payloadData: string;
    }
    /** Information about the cached resource. */
    interface CachedResource {
        /** Resource URL. This is the url of the original network request. */
        url: string;
        /** Type of this resource. */
        type: Page.ResourceType;
        /** Cached response data. */
        response?: Response;
        /** Cached response body size. */
        bodySize: number;
    }
    /** Information about the request initiator. */
    interface Initiator {
        /** Type of this initiator. */
        type: "parser" | "script" | "other";
        /** Initiator JavaScript stack trace, set for Script only. */
        stackTrace?: Console.StackTrace;
        /** Initiator URL, set for Parser type only. */
        url?: string;
        /** Initiator line number, set for Parser type only. */
        lineNumber?: number;
        /** Initiator asynchronous JavaScript stack trace, if available. */
        asyncStackTrace?: Console.AsyncStackTrace;
    }
    /** Cookie object */
    interface Cookie {
        /** Cookie name. */
        name: string;
        /** Cookie value. */
        value: string;
        /** Cookie domain. */
        domain: string;
        /** Cookie path. */
        path: string;
        /** Cookie expires. */
        expires: number;
        /** Cookie size. */
        size: number;
        /** True if cookie is http-only. */
        httpOnly: boolean;
        /** True if cookie is secure. */
        secure: boolean;
        /** True in case of session cookie. */
        session: boolean;
    }
    type requestWillBeSent_Parameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Frame identifier. */
        frameId: Page.FrameId;
        /** Loader identifier. */
        loaderId: LoaderId;
        /** URL of the document this request is loaded for. */
        documentURL: string;
        /** Request data. */
        request: Request;
        /** Timestamp. */
        timestamp: Timestamp;
        /** UTC Timestamp. */
        wallTime: Timestamp;
        /** Request initiator. */
        initiator: Initiator;
        /** Redirect response data. */
        redirectResponse?: Response;
        /** Type of this resource. */
        type?: Page.ResourceType;
    };
    type requestWillBeSent_Handler = (params: requestWillBeSent_Parameters) => void;
    type requestServedFromCache_Parameters = {
        /** Request identifier. */
        requestId: RequestId;
    };
    type requestServedFromCache_Handler = (params: requestServedFromCache_Parameters) => void;
    type responseReceived_Parameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Frame identifier. */
        frameId: Page.FrameId;
        /** Loader identifier. */
        loaderId: LoaderId;
        /** Timestamp. */
        timestamp: Timestamp;
        /** Resource type. */
        type: Page.ResourceType;
        /** Response data. */
        response: Response;
    };
    type responseReceived_Handler = (params: responseReceived_Parameters) => void;
    type dataReceived_Parameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: Timestamp;
        /** Data chunk length. */
        dataLength: number;
        /** Actual bytes received (might be less than dataLength for compressed encodings). */
        encodedDataLength: number;
    };
    type dataReceived_Handler = (params: dataReceived_Parameters) => void;
    type loadingFinished_Parameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: Timestamp;
        /** Total number of bytes received for this request. */
        encodedDataLength: number;
    };
    type loadingFinished_Handler = (params: loadingFinished_Parameters) => void;
    type loadingFailed_Parameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: Timestamp;
        /** Resource type. */
        type: Page.ResourceType;
        /** User friendly error message. */
        errorText: string;
        /** True if loading was canceled. */
        canceled?: boolean;
        /** The reason why loading was blocked, if any. */
        blockedReason?: BlockedReason;
    };
    type loadingFailed_Handler = (params: loadingFailed_Parameters) => void;
    type webSocketWillSendHandshakeRequest_Parameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: Timestamp;
        /** UTC Timestamp. */
        wallTime: Timestamp;
        /** WebSocket request data. */
        request: WebSocketRequest;
    };
    type webSocketWillSendHandshakeRequest_Handler = (params: webSocketWillSendHandshakeRequest_Parameters) => void;
    type webSocketHandshakeResponseReceived_Parameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: Timestamp;
        /** WebSocket response data. */
        response: WebSocketResponse;
    };
    type webSocketHandshakeResponseReceived_Handler = (params: webSocketHandshakeResponseReceived_Parameters) => void;
    type webSocketCreated_Parameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** WebSocket request URL. */
        url: string;
    };
    type webSocketCreated_Handler = (params: webSocketCreated_Parameters) => void;
    type webSocketClosed_Parameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: Timestamp;
    };
    type webSocketClosed_Handler = (params: webSocketClosed_Parameters) => void;
    type webSocketFrameReceived_Parameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: Timestamp;
        /** WebSocket response data. */
        response: WebSocketFrame;
    };
    type webSocketFrameReceived_Handler = (params: webSocketFrameReceived_Parameters) => void;
    type webSocketFrameError_Parameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: Timestamp;
        /** WebSocket frame error message. */
        errorMessage: string;
    };
    type webSocketFrameError_Handler = (params: webSocketFrameError_Parameters) => void;
    type webSocketFrameSent_Parameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: Timestamp;
        /** WebSocket response data. */
        response: WebSocketFrame;
    };
    type webSocketFrameSent_Handler = (params: webSocketFrameSent_Parameters) => void;
    type eventSourceMessageReceived_Parameters = {
        /** Request identifier. */
        requestId: RequestId;
        /** Timestamp. */
        timestamp: Timestamp;
        /** Message type. */
        eventName: string;
        /** Message identifier. */
        eventId: string;
        /** Message content. */
        data: string;
    };
    type eventSourceMessageReceived_Handler = (params: eventSourceMessageReceived_Parameters) => void;
    type setUserAgentOverride_Parameters = {
        /** User agent to use. */
        userAgent: string;
    };
    type setExtraHTTPHeaders_Parameters = {
        /** Map with extra HTTP headers. */
        headers: Headers;
    };
    type getResponseBody_Parameters = {
        /** Identifier of the network request to get content for. */
        requestId: RequestId;
    };
    type getResponseBody_Return = {
        /** Response body. */
        body: string;
        /** True, if content was sent as base64. */
        base64Encoded: boolean;
    };
    type addBlockedURL_Parameters = {
        /** URL to block. */
        url: string;
    };
    type removeBlockedURL_Parameters = {
        /** URL to stop blocking. */
        url: string;
    };
    type replayXHR_Parameters = {
        /** Identifier of XHR to replay. */
        requestId: RequestId;
    };
    type setMonitoringXHREnabled_Parameters = {
        /** Monitoring enabled state. */
        enabled: boolean;
    };
    type canClearBrowserCache_Return = {
        /** True if browser cache can be cleared. */
        result: boolean;
    };
    type canClearBrowserCookies_Return = {
        /** True if browser cookies can be cleared. */
        result: boolean;
    };
    type getCookies_Return = {
        /** Array of cookie objects. */
        cookies: Cookie[];
    };
    type deleteCookie_Parameters = {
        /** Name of the cookie to remove. */
        cookieName: string;
        /** URL to match cooke domain and path. */
        url: string;
    };
    type canEmulateNetworkConditions_Return = {
        /** True if emulation of network conditions is supported. */
        result: boolean;
    };
    type emulateNetworkConditions_Parameters = {
        /** True to emulate internet disconnection. */
        offline: boolean;
        /** Additional latency (ms). */
        latency: number;
        /** Maximal aggregated download throughput. */
        downloadThroughput: number;
        /** Maximal aggregated upload throughput. */
        uploadThroughput: number;
    };
    type setCacheDisabled_Parameters = {
        /** Cache disabled state. */
        cacheDisabled: boolean;
    };
    type setDataSizeLimitsForTest_Parameters = {
        /** Maximum total buffer size. */
        maxTotalSize: number;
        /** Maximum per-resource size. */
        maxResourceSize: number;
    };
    type getCertificateDetails_Parameters = {
        /** ID of the certificate to get details for. */
        certificateId: CertificateId;
    };
    type getCertificateDetails_Return = {
        /** Certificate details. */
        result: CertificateDetails;
    };
    type showCertificateViewer_Parameters = {
        /** Certificate id. */
        certificateId: CertificateId;
    };
}
export declare class Database {
    private _addDatabase;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Enables database tracking, database events will now be delivered to the client. */
    enable(): Promise<void>;
    /** Disables database tracking, prevents database events from being sent to the client. */
    disable(): Promise<void>;
    getDatabaseTableNames(params: Database.getDatabaseTableNames_Parameters): Promise<Database.getDatabaseTableNames_Return>;
    executeSQL(params: Database.executeSQL_Parameters): Promise<Database.executeSQL_Return>;
    addDatabase: Database.addDatabase_Handler;
}
export declare namespace Database {
    /** Unique identifier of Database object. */
    type DatabaseId = string;
    /** Database object. */
    interface Database {
        /** Database ID. */
        id: DatabaseId;
        /** Database domain. */
        domain: string;
        /** Database name. */
        name: string;
        /** Database version. */
        version: string;
    }
    /** Database error. */
    interface Error {
        /** Error message. */
        message: string;
        /** Error code. */
        code: number;
    }
    type addDatabase_Parameters = {
        database: Database;
    };
    type addDatabase_Handler = (params: addDatabase_Parameters) => void;
    type getDatabaseTableNames_Parameters = {
        databaseId: DatabaseId;
    };
    type getDatabaseTableNames_Return = {
        tableNames: string[];
    };
    type executeSQL_Parameters = {
        databaseId: DatabaseId;
        query: string;
    };
    type executeSQL_Return = {
        columnNames?: string[];
        values?: any[];
        sqlError?: Error;
    };
}
export declare class IndexedDB {
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Enables events from backend. */
    enable(): Promise<void>;
    /** Disables events from backend. */
    disable(): Promise<void>;
    /** Requests database names for given security origin. */
    requestDatabaseNames(params: IndexedDB.requestDatabaseNames_Parameters): Promise<IndexedDB.requestDatabaseNames_Return>;
    /** Requests database with given name in given frame. */
    requestDatabase(params: IndexedDB.requestDatabase_Parameters): Promise<IndexedDB.requestDatabase_Return>;
    /** Requests data from object store or index. */
    requestData(params: IndexedDB.requestData_Parameters): Promise<IndexedDB.requestData_Return>;
    /** Clears all entries from an object store. */
    clearObjectStore(params: IndexedDB.clearObjectStore_Parameters): Promise<IndexedDB.clearObjectStore_Return>;
}
export declare namespace IndexedDB {
    /** Database with an array of object stores. */
    interface DatabaseWithObjectStores {
        /** Database name. */
        name: string;
        /** Deprecated string database version. */
        version: string;
        /** Integer database version. */
        intVersion: number;
        /** Object stores in this database. */
        objectStores: ObjectStore[];
    }
    /** Object store. */
    interface ObjectStore {
        /** Object store name. */
        name: string;
        /** Object store key path. */
        keyPath: KeyPath;
        /** If true, object store has auto increment flag set. */
        autoIncrement: boolean;
        /** Indexes in this object store. */
        indexes: ObjectStoreIndex[];
    }
    /** Object store index. */
    interface ObjectStoreIndex {
        /** Index name. */
        name: string;
        /** Index key path. */
        keyPath: KeyPath;
        /** If true, index is unique. */
        unique: boolean;
        /** If true, index allows multiple entries for a key. */
        multiEntry: boolean;
    }
    /** Key. */
    interface Key {
        /** Key type. */
        type: "number" | "string" | "date" | "array";
        /** Number value. */
        number?: number;
        /** String value. */
        string?: string;
        /** Date value. */
        date?: number;
        /** Array value. */
        array?: Key[];
    }
    /** Key range. */
    interface KeyRange {
        /** Lower bound. */
        lower?: Key;
        /** Upper bound. */
        upper?: Key;
        /** If true lower bound is open. */
        lowerOpen: boolean;
        /** If true upper bound is open. */
        upperOpen: boolean;
    }
    /** Data entry. */
    interface DataEntry {
        /** JSON-stringified key object. */
        key: string;
        /** JSON-stringified primary key object. */
        primaryKey: string;
        /** JSON-stringified value object. */
        value: string;
    }
    /** Key path. */
    interface KeyPath {
        /** Key path type. */
        type: "null" | "string" | "array";
        /** String value. */
        string?: string;
        /** Array value. */
        array?: string[];
    }
    type requestDatabaseNames_Parameters = {
        /** Security origin. */
        securityOrigin: string;
    };
    type requestDatabaseNames_Return = {
        /** Database names for origin. */
        databaseNames: string[];
    };
    type requestDatabase_Parameters = {
        /** Security origin. */
        securityOrigin: string;
        /** Database name. */
        databaseName: string;
    };
    type requestDatabase_Return = {
        /** Database with an array of object stores. */
        databaseWithObjectStores: DatabaseWithObjectStores;
    };
    type requestData_Parameters = {
        /** Security origin. */
        securityOrigin: string;
        /** Database name. */
        databaseName: string;
        /** Object store name. */
        objectStoreName: string;
        /** Index name, empty string for object store data requests. */
        indexName: string;
        /** Number of records to skip. */
        skipCount: number;
        /** Number of records to fetch. */
        pageSize: number;
        /** Key range. */
        keyRange?: KeyRange;
    };
    type requestData_Return = {
        /** Array of object store data entries. */
        objectStoreDataEntries: DataEntry[];
        /** If true, there are more entries to fetch in the given range. */
        hasMore: boolean;
    };
    type clearObjectStore_Parameters = {
        /** Security origin. */
        securityOrigin: string;
        /** Database name. */
        databaseName: string;
        /** Object store name. */
        objectStoreName: string;
    };
    type clearObjectStore_Return = any;
}
export declare class CacheStorage {
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Requests cache names. */
    requestCacheNames(params: CacheStorage.requestCacheNames_Parameters): Promise<CacheStorage.requestCacheNames_Return>;
    /** Requests data from cache. */
    requestEntries(params: CacheStorage.requestEntries_Parameters): Promise<CacheStorage.requestEntries_Return>;
    /** Deletes a cache. */
    deleteCache(params: CacheStorage.deleteCache_Parameters): Promise<void>;
    /** Deletes a cache entry. */
    deleteEntry(params: CacheStorage.deleteEntry_Parameters): Promise<void>;
}
export declare namespace CacheStorage {
    /** Unique identifier of the Cache object. */
    type CacheId = string;
    /** Data entry. */
    interface DataEntry {
        /** Request url spec. */
        request: string;
        /** Response stataus text. */
        response: string;
    }
    /** Cache identifier. */
    interface Cache {
        /** An opaque unique id of the cache. */
        cacheId: CacheId;
        /** Security origin of the cache. */
        securityOrigin: string;
        /** The name of the cache. */
        cacheName: string;
    }
    type requestCacheNames_Parameters = {
        /** Security origin. */
        securityOrigin: string;
    };
    type requestCacheNames_Return = {
        /** Caches for the security origin. */
        caches: Cache[];
    };
    type requestEntries_Parameters = {
        /** ID of cache to get entries from. */
        cacheId: CacheId;
        /** Number of records to skip. */
        skipCount: number;
        /** Number of records to fetch. */
        pageSize: number;
    };
    type requestEntries_Return = {
        /** Array of object store data entries. */
        cacheDataEntries: DataEntry[];
        /** If true, there are more entries to fetch in the given range. */
        hasMore: boolean;
    };
    type deleteCache_Parameters = {
        /** Id of cache for deletion. */
        cacheId: CacheId;
    };
    type deleteEntry_Parameters = {
        /** Id of cache where the entry will be deleted. */
        cacheId: CacheId;
        /** URL spec of the request. */
        request: string;
    };
}
/** Query and modify DOM storage. */
export declare class DOMStorage {
    private _domStorageItemsCleared;
    private _domStorageItemRemoved;
    private _domStorageItemAdded;
    private _domStorageItemUpdated;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Enables storage tracking, storage events will now be delivered to the client. */
    enable(): Promise<void>;
    /** Disables storage tracking, prevents storage events from being sent to the client. */
    disable(): Promise<void>;
    getDOMStorageItems(params: DOMStorage.getDOMStorageItems_Parameters): Promise<DOMStorage.getDOMStorageItems_Return>;
    setDOMStorageItem(params: DOMStorage.setDOMStorageItem_Parameters): Promise<void>;
    removeDOMStorageItem(params: DOMStorage.removeDOMStorageItem_Parameters): Promise<void>;
    domStorageItemsCleared: DOMStorage.domStorageItemsCleared_Handler;
    domStorageItemRemoved: DOMStorage.domStorageItemRemoved_Handler;
    domStorageItemAdded: DOMStorage.domStorageItemAdded_Handler;
    domStorageItemUpdated: DOMStorage.domStorageItemUpdated_Handler;
}
export declare namespace DOMStorage {
    /** DOM Storage identifier. */
    interface StorageId {
        /** Security origin for the storage. */
        securityOrigin: string;
        /** Whether the storage is local storage (not session storage). */
        isLocalStorage: boolean;
    }
    /** DOM Storage item. */
    type Item = string[];
    type domStorageItemsCleared_Parameters = {
        storageId: StorageId;
    };
    type domStorageItemsCleared_Handler = (params: domStorageItemsCleared_Parameters) => void;
    type domStorageItemRemoved_Parameters = {
        storageId: StorageId;
        key: string;
    };
    type domStorageItemRemoved_Handler = (params: domStorageItemRemoved_Parameters) => void;
    type domStorageItemAdded_Parameters = {
        storageId: StorageId;
        key: string;
        newValue: string;
    };
    type domStorageItemAdded_Handler = (params: domStorageItemAdded_Parameters) => void;
    type domStorageItemUpdated_Parameters = {
        storageId: StorageId;
        key: string;
        oldValue: string;
        newValue: string;
    };
    type domStorageItemUpdated_Handler = (params: domStorageItemUpdated_Parameters) => void;
    type getDOMStorageItems_Parameters = {
        storageId: StorageId;
    };
    type getDOMStorageItems_Return = {
        entries: Item[];
    };
    type setDOMStorageItem_Parameters = {
        storageId: StorageId;
        key: string;
        value: string;
    };
    type removeDOMStorageItem_Parameters = {
        storageId: StorageId;
        key: string;
    };
}
export declare class ApplicationCache {
    private _applicationCacheStatusUpdated;
    private _networkStateUpdated;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Returns array of frame identifiers with manifest urls for each frame containing a document associated with some application cache. */
    getFramesWithManifests(): Promise<ApplicationCache.getFramesWithManifests_Return>;
    /** Enables application cache domain notifications. */
    enable(): Promise<void>;
    /** Returns manifest URL for document in the given frame. */
    getManifestForFrame(params: ApplicationCache.getManifestForFrame_Parameters): Promise<ApplicationCache.getManifestForFrame_Return>;
    /** Returns relevant application cache data for the document in given frame. */
    getApplicationCacheForFrame(params: ApplicationCache.getApplicationCacheForFrame_Parameters): Promise<ApplicationCache.getApplicationCacheForFrame_Return>;
    applicationCacheStatusUpdated: ApplicationCache.applicationCacheStatusUpdated_Handler;
    networkStateUpdated: ApplicationCache.networkStateUpdated_Handler;
}
export declare namespace ApplicationCache {
    /** Detailed application cache resource information. */
    interface ApplicationCacheResource {
        /** Resource url. */
        url: string;
        /** Resource size. */
        size: number;
        /** Resource type. */
        type: string;
    }
    /** Detailed application cache information. */
    interface ApplicationCache {
        /** Manifest URL. */
        manifestURL: string;
        /** Application cache size. */
        size: number;
        /** Application cache creation time. */
        creationTime: number;
        /** Application cache update time. */
        updateTime: number;
        /** Application cache resources. */
        resources: ApplicationCacheResource[];
    }
    /** Frame identifier - manifest URL pair. */
    interface FrameWithManifest {
        /** Frame identifier. */
        frameId: Page.FrameId;
        /** Manifest URL. */
        manifestURL: string;
        /** Application cache status. */
        status: number;
    }
    type applicationCacheStatusUpdated_Parameters = {
        /** Identifier of the frame containing document whose application cache updated status. */
        frameId: Page.FrameId;
        /** Manifest URL. */
        manifestURL: string;
        /** Updated application cache status. */
        status: number;
    };
    type applicationCacheStatusUpdated_Handler = (params: applicationCacheStatusUpdated_Parameters) => void;
    type networkStateUpdated_Parameters = {
        isNowOnline: boolean;
    };
    type networkStateUpdated_Handler = (params: networkStateUpdated_Parameters) => void;
    type getFramesWithManifests_Return = {
        /** Array of frame identifiers with manifest urls for each frame containing a document associated with some application cache. */
        frameIds: FrameWithManifest[];
    };
    type getManifestForFrame_Parameters = {
        /** Identifier of the frame containing document whose manifest is retrieved. */
        frameId: Page.FrameId;
    };
    type getManifestForFrame_Return = {
        /** Manifest URL for document in the given frame. */
        manifestURL: string;
    };
    type getApplicationCacheForFrame_Parameters = {
        /** Identifier of the frame containing document whose application cache is retrieved. */
        frameId: Page.FrameId;
    };
    type getApplicationCacheForFrame_Return = {
        /** Relevant application cache data for the document in given frame. */
        applicationCache: ApplicationCache;
    };
}
export declare class FileSystem {
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Enables events from backend. */
    enable(): Promise<void>;
    /** Disables events from backend. */
    disable(): Promise<void>;
    /** Returns root directory of the FileSystem, if exists. */
    requestFileSystemRoot(params: FileSystem.requestFileSystemRoot_Parameters): Promise<FileSystem.requestFileSystemRoot_Return>;
    /** Returns content of the directory. */
    requestDirectoryContent(params: FileSystem.requestDirectoryContent_Parameters): Promise<FileSystem.requestDirectoryContent_Return>;
    /** Returns metadata of the entry. */
    requestMetadata(params: FileSystem.requestMetadata_Parameters): Promise<FileSystem.requestMetadata_Return>;
    /** Returns content of the file. Result should be sliced into [start, end). */
    requestFileContent(params: FileSystem.requestFileContent_Parameters): Promise<FileSystem.requestFileContent_Return>;
    /** Deletes specified entry. If the entry is a directory, the agent deletes children recursively. */
    deleteEntry(params: FileSystem.deleteEntry_Parameters): Promise<FileSystem.deleteEntry_Return>;
}
export declare namespace FileSystem {
    /** Represents a browser side file or directory. */
    interface Entry {
        /** filesystem: URL for the entry. */
        url: string;
        /** The name of the file or directory. */
        name: string;
        /** True if the entry is a directory. */
        isDirectory: boolean;
        /** MIME type of the entry, available for a file only. */
        mimeType?: string;
        /** ResourceType of the entry, available for a file only. */
        resourceType?: Page.ResourceType;
        /** True if the entry is a text file. */
        isTextFile?: boolean;
    }
    /** Represents metadata of a file or entry. */
    interface Metadata {
        /** Modification time. */
        modificationTime: number;
        /** File size. This field is always zero for directories. */
        size: number;
    }
    type requestFileSystemRoot_Parameters = {
        /** Security origin of requesting FileSystem. One of frames in current page needs to have this security origin. */
        origin: string;
        /** FileSystem type of requesting FileSystem. */
        type: "temporary" | "persistent";
    };
    type requestFileSystemRoot_Return = {
        /** 0, if no error. Otherwise, errorCode is set to FileError::ErrorCode value. */
        errorCode: number;
        /** Contains root of the requested FileSystem if the command completed successfully. */
        root?: Entry;
    };
    type requestDirectoryContent_Parameters = {
        /** URL of the directory that the frontend is requesting to read from. */
        url: string;
    };
    type requestDirectoryContent_Return = {
        /** 0, if no error. Otherwise, errorCode is set to FileError::ErrorCode value. */
        errorCode: number;
        /** Contains all entries on directory if the command completed successfully. */
        entries?: Entry[];
    };
    type requestMetadata_Parameters = {
        /** URL of the entry that the frontend is requesting to get metadata from. */
        url: string;
    };
    type requestMetadata_Return = {
        /** 0, if no error. Otherwise, errorCode is set to FileError::ErrorCode value. */
        errorCode: number;
        /** Contains metadata of the entry if the command completed successfully. */
        metadata?: Metadata;
    };
    type requestFileContent_Parameters = {
        /** URL of the file that the frontend is requesting to read from. */
        url: string;
        /** True if the content should be read as text, otherwise the result will be returned as base64 encoded text. */
        readAsText: boolean;
        /** Specifies the start of range to read. */
        start?: number;
        /** Specifies the end of range to read exclusively. */
        end?: number;
        /** Overrides charset of the content when content is served as text. */
        charset?: string;
    };
    type requestFileContent_Return = {
        /** 0, if no error. Otherwise, errorCode is set to FileError::ErrorCode value. */
        errorCode: number;
        /** Content of the file. */
        content?: string;
        /** Charset of the content if it is served as text. */
        charset?: string;
    };
    type deleteEntry_Parameters = {
        /** URL of the entry to delete. */
        url: string;
    };
    type deleteEntry_Return = {
        /** 0, if no error. Otherwise errorCode is set to FileError::ErrorCode value. */
        errorCode: number;
    };
}
/** This domain exposes DOM read/write operations. Each DOM Node is represented with its mirror object that has an <code>id</code>. This <code>id</code> can be used to get additional information on the Node, resolve it into the JavaScript object wrapper, etc. It is important that client receives DOM events only for the nodes that are known to the client. Backend keeps track of the nodes that were sent to the client and never sends the same node twice. It is client's responsibility to collect information about the nodes that were sent to the client.<p>Note that <code>iframe</code> owner elements will return corresponding document elements as their child nodes.</p> */
export declare class DOM {
    private _documentUpdated;
    private _inspectNodeRequested;
    private _setChildNodes;
    private _attributeModified;
    private _attributeRemoved;
    private _inlineStyleInvalidated;
    private _characterDataModified;
    private _childNodeCountUpdated;
    private _childNodeInserted;
    private _childNodeRemoved;
    private _shadowRootPushed;
    private _shadowRootPopped;
    private _pseudoElementAdded;
    private _pseudoElementRemoved;
    private _distributedNodesUpdated;
    private _nodeHighlightRequested;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Enables DOM agent for the given page. */
    enable(): Promise<void>;
    /** Disables DOM agent for the given page. */
    disable(): Promise<void>;
    /** Returns the root DOM node to the caller. */
    getDocument(): Promise<DOM.getDocument_Return>;
    /** Requests that children of the node with given id are returned to the caller in form of <code>setChildNodes</code> events where not only immediate children are retrieved, but all children down to the specified depth. */
    requestChildNodes(params: DOM.requestChildNodes_Parameters): Promise<void>;
    /** Executes <code>querySelector</code> on a given node. */
    querySelector(params: DOM.querySelector_Parameters): Promise<DOM.querySelector_Return>;
    /** Executes <code>querySelectorAll</code> on a given node. */
    querySelectorAll(params: DOM.querySelectorAll_Parameters): Promise<DOM.querySelectorAll_Return>;
    /** Sets node name for a node with given id. */
    setNodeName(params: DOM.setNodeName_Parameters): Promise<DOM.setNodeName_Return>;
    /** Sets node value for a node with given id. */
    setNodeValue(params: DOM.setNodeValue_Parameters): Promise<void>;
    /** Removes node with given id. */
    removeNode(params: DOM.removeNode_Parameters): Promise<void>;
    /** Sets attribute for an element with given id. */
    setAttributeValue(params: DOM.setAttributeValue_Parameters): Promise<void>;
    /** Sets attributes on element with given id. This method is useful when user edits some existing attribute value and types in several attribute name/value pairs. */
    setAttributesAsText(params: DOM.setAttributesAsText_Parameters): Promise<void>;
    /** Removes attribute with given name from an element with given id. */
    removeAttribute(params: DOM.removeAttribute_Parameters): Promise<void>;
    /** Returns node's HTML markup. */
    getOuterHTML(params: DOM.getOuterHTML_Parameters): Promise<DOM.getOuterHTML_Return>;
    /** Sets node HTML markup, returns new node id. */
    setOuterHTML(params: DOM.setOuterHTML_Parameters): Promise<void>;
    /** Searches for a given string in the DOM tree. Use <code>getSearchResults</code> to access search results or <code>cancelSearch</code> to end this search session. */
    performSearch(params: DOM.performSearch_Parameters): Promise<DOM.performSearch_Return>;
    /** Returns search results from given <code>fromIndex</code> to given <code>toIndex</code> from the sarch with the given identifier. */
    getSearchResults(params: DOM.getSearchResults_Parameters): Promise<DOM.getSearchResults_Return>;
    /** Discards search results from the session with the given id. <code>getSearchResults</code> should no longer be called for that search. */
    discardSearchResults(params: DOM.discardSearchResults_Parameters): Promise<void>;
    /** Requests that the node is sent to the caller given the JavaScript node object reference. All nodes that form the path from the node to the root are also sent to the client as a series of <code>setChildNodes</code> notifications. */
    requestNode(params: DOM.requestNode_Parameters): Promise<DOM.requestNode_Return>;
    /** Enters the 'inspect' mode. In this mode, elements that user is hovering over are highlighted. Backend then generates 'inspectNodeRequested' event upon element selection. */
    setInspectMode(params: DOM.setInspectMode_Parameters): Promise<void>;
    /** Highlights given rectangle. Coordinates are absolute with respect to the main frame viewport. */
    highlightRect(params: DOM.highlightRect_Parameters): Promise<void>;
    /** Highlights given quad. Coordinates are absolute with respect to the main frame viewport. */
    highlightQuad(params: DOM.highlightQuad_Parameters): Promise<void>;
    /** Highlights DOM node with given id or with the given JavaScript object wrapper. Either nodeId or objectId must be specified. */
    highlightNode(params: DOM.highlightNode_Parameters): Promise<void>;
    /** Hides DOM node highlight. */
    hideHighlight(): Promise<void>;
    /** Highlights owner element of the frame with given id. */
    highlightFrame(params: DOM.highlightFrame_Parameters): Promise<void>;
    /** Requests that the node is sent to the caller given its path. // FIXME, use XPath */
    pushNodeByPathToFrontend(params: DOM.pushNodeByPathToFrontend_Parameters): Promise<DOM.pushNodeByPathToFrontend_Return>;
    /** Requests that a batch of nodes is sent to the caller given their backend node ids. */
    pushNodesByBackendIdsToFrontend(params: DOM.pushNodesByBackendIdsToFrontend_Parameters): Promise<DOM.pushNodesByBackendIdsToFrontend_Return>;
    /** Enables console to refer to the node with given id via $x (see Command Line API for more details $x functions). */
    setInspectedNode(params: DOM.setInspectedNode_Parameters): Promise<void>;
    /** Resolves JavaScript node object for given node id. */
    resolveNode(params: DOM.resolveNode_Parameters): Promise<DOM.resolveNode_Return>;
    /** Returns attributes for the specified node. */
    getAttributes(params: DOM.getAttributes_Parameters): Promise<DOM.getAttributes_Return>;
    /** Creates a deep copy of the specified node and places it into the target container before the given anchor. */
    copyTo(params: DOM.copyTo_Parameters): Promise<DOM.copyTo_Return>;
    /** Moves node into the new container, places it before the given anchor. */
    moveTo(params: DOM.moveTo_Parameters): Promise<DOM.moveTo_Return>;
    /** Undoes the last performed action. */
    undo(): Promise<void>;
    /** Re-does the last undone action. */
    redo(): Promise<void>;
    /** Marks last undoable state. */
    markUndoableState(): Promise<void>;
    /** Focuses the given element. */
    focus(params: DOM.focus_Parameters): Promise<void>;
    /** Sets files for the given file input element. */
    setFileInputFiles(params: DOM.setFileInputFiles_Parameters): Promise<void>;
    /** Returns boxes for the currently selected nodes. */
    getBoxModel(params: DOM.getBoxModel_Parameters): Promise<DOM.getBoxModel_Return>;
    /** Returns node id at given location. */
    getNodeForLocation(params: DOM.getNodeForLocation_Parameters): Promise<DOM.getNodeForLocation_Return>;
    /** Returns the id of the nearest ancestor that is a relayout boundary. */
    getRelayoutBoundary(params: DOM.getRelayoutBoundary_Parameters): Promise<DOM.getRelayoutBoundary_Return>;
    /** For testing. */
    getHighlightObjectForTest(params: DOM.getHighlightObjectForTest_Parameters): Promise<DOM.getHighlightObjectForTest_Return>;
    /** Fired when <code>Document</code> has been totally updated. Node ids are no longer valid. */
    documentUpdated: DOM.documentUpdated_Handler;
    /** Fired when the node should be inspected. This happens after call to <code>setInspectMode</code>. */
    inspectNodeRequested: DOM.inspectNodeRequested_Handler;
    /** Fired when backend wants to provide client with the missing DOM structure. This happens upon most of the calls requesting node ids. */
    setChildNodes: DOM.setChildNodes_Handler;
    /** Fired when <code>Element</code>'s attribute is modified. */
    attributeModified: DOM.attributeModified_Handler;
    /** Fired when <code>Element</code>'s attribute is removed. */
    attributeRemoved: DOM.attributeRemoved_Handler;
    /** Fired when <code>Element</code>'s inline style is modified via a CSS property modification. */
    inlineStyleInvalidated: DOM.inlineStyleInvalidated_Handler;
    /** Mirrors <code>DOMCharacterDataModified</code> event. */
    characterDataModified: DOM.characterDataModified_Handler;
    /** Fired when <code>Container</code>'s child node count has changed. */
    childNodeCountUpdated: DOM.childNodeCountUpdated_Handler;
    /** Mirrors <code>DOMNodeInserted</code> event. */
    childNodeInserted: DOM.childNodeInserted_Handler;
    /** Mirrors <code>DOMNodeRemoved</code> event. */
    childNodeRemoved: DOM.childNodeRemoved_Handler;
    /** Called when shadow root is pushed into the element. */
    shadowRootPushed: DOM.shadowRootPushed_Handler;
    /** Called when shadow root is popped from the element. */
    shadowRootPopped: DOM.shadowRootPopped_Handler;
    /** Called when a pseudo element is added to an element. */
    pseudoElementAdded: DOM.pseudoElementAdded_Handler;
    /** Called when a pseudo element is removed from an element. */
    pseudoElementRemoved: DOM.pseudoElementRemoved_Handler;
    /** Called when distrubution is changed. */
    distributedNodesUpdated: DOM.distributedNodesUpdated_Handler;
    nodeHighlightRequested: DOM.nodeHighlightRequested_Handler;
}
export declare namespace DOM {
    /** Unique DOM node identifier. */
    type NodeId = number;
    /** Unique DOM node identifier used to reference a node that may not have been pushed to the front-end. */
    type BackendNodeId = number;
    /** Backend node with a friendly name. */
    interface BackendNode {
        /** <code>Node</code>'s nodeType. */
        nodeType: number;
        /** <code>Node</code>'s nodeName. */
        nodeName: string;
        backendNodeId: BackendNodeId;
    }
    /** Pseudo element type. */
    type PseudoType = "first-line" | "first-letter" | "before" | "after" | "backdrop" | "selection" | "first-line-inherited" | "scrollbar" | "scrollbar-thumb" | "scrollbar-button" | "scrollbar-track" | "scrollbar-track-piece" | "scrollbar-corner" | "resizer" | "input-list-button";
    /** Shadow root type. */
    type ShadowRootType = "user-agent" | "open" | "closed";
    /** DOM interaction is implemented in terms of mirror objects that represent the actual DOM nodes. DOMNode is a base node mirror type. */
    interface Node {
        /** Node identifier that is passed into the rest of the DOM messages as the <code>nodeId</code>. Backend will only push node with given <code>id</code> once. It is aware of all requested nodes and will only fire DOM events for nodes known to the client. */
        nodeId: NodeId;
        /** <code>Node</code>'s nodeType. */
        nodeType: number;
        /** <code>Node</code>'s nodeName. */
        nodeName: string;
        /** <code>Node</code>'s localName. */
        localName: string;
        /** <code>Node</code>'s nodeValue. */
        nodeValue: string;
        /** Child count for <code>Container</code> nodes. */
        childNodeCount?: number;
        /** Child nodes of this node when requested with children. */
        children?: Node[];
        /** Attributes of the <code>Element</code> node in the form of flat array <code>[name1, value1, name2, value2]</code>. */
        attributes?: string[];
        /** Document URL that <code>Document</code> or <code>FrameOwner</code> node points to. */
        documentURL?: string;
        /** Base URL that <code>Document</code> or <code>FrameOwner</code> node uses for URL completion. */
        baseURL?: string;
        /** <code>DocumentType</code>'s publicId. */
        publicId?: string;
        /** <code>DocumentType</code>'s systemId. */
        systemId?: string;
        /** <code>DocumentType</code>'s internalSubset. */
        internalSubset?: string;
        /** <code>Document</code>'s XML version in case of XML documents. */
        xmlVersion?: string;
        /** <code>Attr</code>'s name. */
        name?: string;
        /** <code>Attr</code>'s value. */
        value?: string;
        /** Pseudo element type for this node. */
        pseudoType?: PseudoType;
        /** Shadow root type. */
        shadowRootType?: ShadowRootType;
        /** Frame ID for frame owner elements. */
        frameId?: Page.FrameId;
        /** Content document for frame owner elements. */
        contentDocument?: Node;
        /** Shadow root list for given element host. */
        shadowRoots?: Node[];
        /** Content document fragment for template elements. */
        templateContent?: Node;
        /** Pseudo elements associated with this node. */
        pseudoElements?: Node[];
        /** Import document for the HTMLImport links. */
        importedDocument?: Node;
        /** Distributed nodes for given insertion point. */
        distributedNodes?: BackendNode[];
    }
    /** A structure holding an RGBA color. */
    interface RGBA {
        /** The red component, in the [0-255] range. */
        r: number;
        /** The green component, in the [0-255] range. */
        g: number;
        /** The blue component, in the [0-255] range. */
        b: number;
        /** The alpha component, in the [0-1] range (default: 1). */
        a?: number;
    }
    /** An array of quad vertices, x immediately followed by y for each point, points clock-wise. */
    type Quad = number[];
    /** Box model. */
    interface BoxModel {
        /** Content box */
        content: Quad;
        /** Padding box */
        padding: Quad;
        /** Border box */
        border: Quad;
        /** Margin box */
        margin: Quad;
        /** Node width */
        width: number;
        /** Node height */
        height: number;
        /** Shape outside coordinates */
        shapeOutside?: ShapeOutsideInfo;
    }
    /** CSS Shape Outside details. */
    interface ShapeOutsideInfo {
        /** Shape bounds */
        bounds: Quad;
        /** Shape coordinate details */
        shape: any[];
        /** Margin shape bounds */
        marginShape: any[];
    }
    /** Rectangle. */
    interface Rect {
        /** X coordinate */
        x: number;
        /** Y coordinate */
        y: number;
        /** Rectangle width */
        width: number;
        /** Rectangle height */
        height: number;
    }
    /** Configuration data for the highlighting of page elements. */
    interface HighlightConfig {
        /** Whether the node info tooltip should be shown (default: false). */
        showInfo?: boolean;
        /** Whether the rulers should be shown (default: false). */
        showRulers?: boolean;
        /** Whether the extension lines from node to the rulers should be shown (default: false). */
        showExtensionLines?: boolean;
        displayAsMaterial?: boolean;
        /** The content box highlight fill color (default: transparent). */
        contentColor?: RGBA;
        /** The padding highlight fill color (default: transparent). */
        paddingColor?: RGBA;
        /** The border highlight fill color (default: transparent). */
        borderColor?: RGBA;
        /** The margin highlight fill color (default: transparent). */
        marginColor?: RGBA;
        /** The event target element highlight fill color (default: transparent). */
        eventTargetColor?: RGBA;
        /** The shape outside fill color (default: transparent). */
        shapeColor?: RGBA;
        /** The shape margin fill color (default: transparent). */
        shapeMarginColor?: RGBA;
        /** Selectors to highlight relevant nodes. */
        selectorList?: string;
    }
    type InspectMode = "searchForNode" | "searchForUAShadowDOM" | "showLayoutEditor" | "none";
    type documentUpdated_Handler = () => void;
    type inspectNodeRequested_Parameters = {
        /** Id of the node to inspect. */
        backendNodeId: BackendNodeId;
    };
    type inspectNodeRequested_Handler = (params: inspectNodeRequested_Parameters) => void;
    type setChildNodes_Parameters = {
        /** Parent node id to populate with children. */
        parentId: NodeId;
        /** Child nodes array. */
        nodes: Node[];
    };
    type setChildNodes_Handler = (params: setChildNodes_Parameters) => void;
    type attributeModified_Parameters = {
        /** Id of the node that has changed. */
        nodeId: NodeId;
        /** Attribute name. */
        name: string;
        /** Attribute value. */
        value: string;
    };
    type attributeModified_Handler = (params: attributeModified_Parameters) => void;
    type attributeRemoved_Parameters = {
        /** Id of the node that has changed. */
        nodeId: NodeId;
        /** A ttribute name. */
        name: string;
    };
    type attributeRemoved_Handler = (params: attributeRemoved_Parameters) => void;
    type inlineStyleInvalidated_Parameters = {
        /** Ids of the nodes for which the inline styles have been invalidated. */
        nodeIds: NodeId[];
    };
    type inlineStyleInvalidated_Handler = (params: inlineStyleInvalidated_Parameters) => void;
    type characterDataModified_Parameters = {
        /** Id of the node that has changed. */
        nodeId: NodeId;
        /** New text value. */
        characterData: string;
    };
    type characterDataModified_Handler = (params: characterDataModified_Parameters) => void;
    type childNodeCountUpdated_Parameters = {
        /** Id of the node that has changed. */
        nodeId: NodeId;
        /** New node count. */
        childNodeCount: number;
    };
    type childNodeCountUpdated_Handler = (params: childNodeCountUpdated_Parameters) => void;
    type childNodeInserted_Parameters = {
        /** Id of the node that has changed. */
        parentNodeId: NodeId;
        /** If of the previous siblint. */
        previousNodeId: NodeId;
        /** Inserted node data. */
        node: Node;
    };
    type childNodeInserted_Handler = (params: childNodeInserted_Parameters) => void;
    type childNodeRemoved_Parameters = {
        /** Parent id. */
        parentNodeId: NodeId;
        /** Id of the node that has been removed. */
        nodeId: NodeId;
    };
    type childNodeRemoved_Handler = (params: childNodeRemoved_Parameters) => void;
    type shadowRootPushed_Parameters = {
        /** Host element id. */
        hostId: NodeId;
        /** Shadow root. */
        root: Node;
    };
    type shadowRootPushed_Handler = (params: shadowRootPushed_Parameters) => void;
    type shadowRootPopped_Parameters = {
        /** Host element id. */
        hostId: NodeId;
        /** Shadow root id. */
        rootId: NodeId;
    };
    type shadowRootPopped_Handler = (params: shadowRootPopped_Parameters) => void;
    type pseudoElementAdded_Parameters = {
        /** Pseudo element's parent element id. */
        parentId: NodeId;
        /** The added pseudo element. */
        pseudoElement: Node;
    };
    type pseudoElementAdded_Handler = (params: pseudoElementAdded_Parameters) => void;
    type pseudoElementRemoved_Parameters = {
        /** Pseudo element's parent element id. */
        parentId: NodeId;
        /** The removed pseudo element id. */
        pseudoElementId: NodeId;
    };
    type pseudoElementRemoved_Handler = (params: pseudoElementRemoved_Parameters) => void;
    type distributedNodesUpdated_Parameters = {
        /** Insertion point where distrubuted nodes were updated. */
        insertionPointId: NodeId;
        /** Distributed nodes for given insertion point. */
        distributedNodes: BackendNode[];
    };
    type distributedNodesUpdated_Handler = (params: distributedNodesUpdated_Parameters) => void;
    type nodeHighlightRequested_Parameters = {
        nodeId: NodeId;
    };
    type nodeHighlightRequested_Handler = (params: nodeHighlightRequested_Parameters) => void;
    type getDocument_Return = {
        /** Resulting node. */
        root: Node;
    };
    type requestChildNodes_Parameters = {
        /** Id of the node to get children for. */
        nodeId: NodeId;
        /** The maximum depth at which children should be retrieved, defaults to 1. Use -1 for the entire subtree or provide an integer larger than 0. */
        depth?: number;
    };
    type querySelector_Parameters = {
        /** Id of the node to query upon. */
        nodeId: NodeId;
        /** Selector string. */
        selector: string;
    };
    type querySelector_Return = {
        /** Query selector result. */
        nodeId: NodeId;
    };
    type querySelectorAll_Parameters = {
        /** Id of the node to query upon. */
        nodeId: NodeId;
        /** Selector string. */
        selector: string;
    };
    type querySelectorAll_Return = {
        /** Query selector result. */
        nodeIds: NodeId[];
    };
    type setNodeName_Parameters = {
        /** Id of the node to set name for. */
        nodeId: NodeId;
        /** New node's name. */
        name: string;
    };
    type setNodeName_Return = {
        /** New node's id. */
        nodeId: NodeId;
    };
    type setNodeValue_Parameters = {
        /** Id of the node to set value for. */
        nodeId: NodeId;
        /** New node's value. */
        value: string;
    };
    type removeNode_Parameters = {
        /** Id of the node to remove. */
        nodeId: NodeId;
    };
    type setAttributeValue_Parameters = {
        /** Id of the element to set attribute for. */
        nodeId: NodeId;
        /** Attribute name. */
        name: string;
        /** Attribute value. */
        value: string;
    };
    type setAttributesAsText_Parameters = {
        /** Id of the element to set attributes for. */
        nodeId: NodeId;
        /** Text with a number of attributes. Will parse this text using HTML parser. */
        text: string;
        /** Attribute name to replace with new attributes derived from text in case text parsed successfully. */
        name?: string;
    };
    type removeAttribute_Parameters = {
        /** Id of the element to remove attribute from. */
        nodeId: NodeId;
        /** Name of the attribute to remove. */
        name: string;
    };
    type getOuterHTML_Parameters = {
        /** Id of the node to get markup for. */
        nodeId: NodeId;
    };
    type getOuterHTML_Return = {
        /** Outer HTML markup. */
        outerHTML: string;
    };
    type setOuterHTML_Parameters = {
        /** Id of the node to set markup for. */
        nodeId: NodeId;
        /** Outer HTML markup to set. */
        outerHTML: string;
    };
    type performSearch_Parameters = {
        /** Plain text or query selector or XPath search query. */
        query: string;
        /** True to search in user agent shadow DOM. */
        includeUserAgentShadowDOM?: boolean;
    };
    type performSearch_Return = {
        /** Unique search session identifier. */
        searchId: string;
        /** Number of search results. */
        resultCount: number;
    };
    type getSearchResults_Parameters = {
        /** Unique search session identifier. */
        searchId: string;
        /** Start index of the search result to be returned. */
        fromIndex: number;
        /** End index of the search result to be returned. */
        toIndex: number;
    };
    type getSearchResults_Return = {
        /** Ids of the search result nodes. */
        nodeIds: NodeId[];
    };
    type discardSearchResults_Parameters = {
        /** Unique search session identifier. */
        searchId: string;
    };
    type requestNode_Parameters = {
        /** JavaScript object id to convert into node. */
        objectId: Runtime.RemoteObjectId;
    };
    type requestNode_Return = {
        /** Node id for given object. */
        nodeId: NodeId;
    };
    type setInspectMode_Parameters = {
        /** Set an inspection mode. */
        mode: InspectMode;
        /** A descriptor for the highlight appearance of hovered-over nodes. May be omitted if <code>enabled == false</code>. */
        highlightConfig?: HighlightConfig;
    };
    type highlightRect_Parameters = {
        /** X coordinate */
        x: number;
        /** Y coordinate */
        y: number;
        /** Rectangle width */
        width: number;
        /** Rectangle height */
        height: number;
        /** The highlight fill color (default: transparent). */
        color?: RGBA;
        /** The highlight outline color (default: transparent). */
        outlineColor?: RGBA;
    };
    type highlightQuad_Parameters = {
        /** Quad to highlight */
        quad: Quad;
        /** The highlight fill color (default: transparent). */
        color?: RGBA;
        /** The highlight outline color (default: transparent). */
        outlineColor?: RGBA;
    };
    type highlightNode_Parameters = {
        /** A descriptor for the highlight appearance. */
        highlightConfig: HighlightConfig;
        /** Identifier of the node to highlight. */
        nodeId?: NodeId;
        /** Identifier of the backend node to highlight. */
        backendNodeId?: BackendNodeId;
        /** JavaScript object id of the node to be highlighted. */
        objectId?: Runtime.RemoteObjectId;
    };
    type highlightFrame_Parameters = {
        /** Identifier of the frame to highlight. */
        frameId: Page.FrameId;
        /** The content box highlight fill color (default: transparent). */
        contentColor?: RGBA;
        /** The content box highlight outline color (default: transparent). */
        contentOutlineColor?: RGBA;
    };
    type pushNodeByPathToFrontend_Parameters = {
        /** Path to node in the proprietary format. */
        path: string;
    };
    type pushNodeByPathToFrontend_Return = {
        /** Id of the node for given path. */
        nodeId: NodeId;
    };
    type pushNodesByBackendIdsToFrontend_Parameters = {
        /** The array of backend node ids. */
        backendNodeIds: BackendNodeId[];
    };
    type pushNodesByBackendIdsToFrontend_Return = {
        /** The array of ids of pushed nodes that correspond to the backend ids specified in backendNodeIds. */
        nodeIds: NodeId[];
    };
    type setInspectedNode_Parameters = {
        /** DOM node id to be accessible by means of $x command line API. */
        nodeId: NodeId;
    };
    type resolveNode_Parameters = {
        /** Id of the node to resolve. */
        nodeId: NodeId;
        /** Symbolic group name that can be used to release multiple objects. */
        objectGroup?: string;
    };
    type resolveNode_Return = {
        /** JavaScript object wrapper for given node. */
        object: Runtime.RemoteObject;
    };
    type getAttributes_Parameters = {
        /** Id of the node to retrieve attibutes for. */
        nodeId: NodeId;
    };
    type getAttributes_Return = {
        /** An interleaved array of node attribute names and values. */
        attributes: string[];
    };
    type copyTo_Parameters = {
        /** Id of the node to copy. */
        nodeId: NodeId;
        /** Id of the element to drop the copy into. */
        targetNodeId: NodeId;
        /** Drop the copy before this node (if absent, the copy becomes the last child of <code>targetNodeId</code>). */
        insertBeforeNodeId?: NodeId;
    };
    type copyTo_Return = {
        /** Id of the node clone. */
        nodeId: NodeId;
    };
    type moveTo_Parameters = {
        /** Id of the node to move. */
        nodeId: NodeId;
        /** Id of the element to drop the moved node into. */
        targetNodeId: NodeId;
        /** Drop node before this one (if absent, the moved node becomes the last child of <code>targetNodeId</code>). */
        insertBeforeNodeId?: NodeId;
    };
    type moveTo_Return = {
        /** New id of the moved node. */
        nodeId: NodeId;
    };
    type focus_Parameters = {
        /** Id of the node to focus. */
        nodeId: NodeId;
    };
    type setFileInputFiles_Parameters = {
        /** Id of the file input node to set files for. */
        nodeId: NodeId;
        /** Array of file paths to set. */
        files: string[];
    };
    type getBoxModel_Parameters = {
        /** Id of the node to get box model for. */
        nodeId: NodeId;
    };
    type getBoxModel_Return = {
        /** Box model for the node. */
        model: BoxModel;
    };
    type getNodeForLocation_Parameters = {
        /** X coordinate. */
        x: number;
        /** Y coordinate. */
        y: number;
    };
    type getNodeForLocation_Return = {
        /** Id of the node at given coordinates. */
        nodeId: NodeId;
    };
    type getRelayoutBoundary_Parameters = {
        /** Id of the node. */
        nodeId: NodeId;
    };
    type getRelayoutBoundary_Return = {
        /** Relayout boundary node id for the given node. */
        nodeId: NodeId;
    };
    type getHighlightObjectForTest_Parameters = {
        /** Id of the node to get highlight object for. */
        nodeId: NodeId;
    };
    type getHighlightObjectForTest_Return = {
        /** Highlight data for the node. */
        highlight: any;
    };
}
/** This domain exposes CSS read/write operations. All CSS objects (stylesheets, rules, and styles) have an associated <code>id</code> used in subsequent operations on the related object. Each object type has a specific <code>id</code> structure, and those are not interchangeable between objects of different kinds. CSS objects can be loaded using the <code>get*ForNode()</code> calls (which accept a DOM node id). A client can also discover all the existing stylesheets with the <code>getAllStyleSheets()</code> method (or keeping track of the <code>styleSheetAdded</code>/<code>styleSheetRemoved</code> events) and subsequently load the required stylesheet contents using the <code>getStyleSheet[Text]()</code> methods. */
export declare class CSS {
    private _mediaQueryResultChanged;
    private _styleSheetChanged;
    private _styleSheetAdded;
    private _styleSheetRemoved;
    private _layoutEditorChange;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Enables the CSS agent for the given page. Clients should not assume that the CSS agent has been enabled until the result of this command is received. */
    enable(): Promise<void>;
    /** Disables the CSS agent for the given page. */
    disable(): Promise<void>;
    /** Returns requested styles for a DOM node identified by <code>nodeId</code>. */
    getMatchedStylesForNode(params: CSS.getMatchedStylesForNode_Parameters): Promise<CSS.getMatchedStylesForNode_Return>;
    /** Returns the styles defined inline (explicitly in the "style" attribute and implicitly, using DOM attributes) for a DOM node identified by <code>nodeId</code>. */
    getInlineStylesForNode(params: CSS.getInlineStylesForNode_Parameters): Promise<CSS.getInlineStylesForNode_Return>;
    /** Returns the computed style for a DOM node identified by <code>nodeId</code>. */
    getComputedStyleForNode(params: CSS.getComputedStyleForNode_Parameters): Promise<CSS.getComputedStyleForNode_Return>;
    /** Requests information about platform fonts which we used to render child TextNodes in the given node. */
    getPlatformFontsForNode(params: CSS.getPlatformFontsForNode_Parameters): Promise<CSS.getPlatformFontsForNode_Return>;
    /** Returns all CSS keyframed animations mtaching this node. */
    getCSSAnimationsForNode(params: CSS.getCSSAnimationsForNode_Parameters): Promise<CSS.getCSSAnimationsForNode_Return>;
    /** Returns the current textual content and the URL for a stylesheet. */
    getStyleSheetText(params: CSS.getStyleSheetText_Parameters): Promise<CSS.getStyleSheetText_Return>;
    /** Sets the new stylesheet text. */
    setStyleSheetText(params: CSS.setStyleSheetText_Parameters): Promise<CSS.setStyleSheetText_Return>;
    /** Modifies the rule selector. */
    setRuleSelector(params: CSS.setRuleSelector_Parameters): Promise<CSS.setRuleSelector_Return>;
    /** Modifies the style text. */
    setStyleText(params: CSS.setStyleText_Parameters): Promise<CSS.setStyleText_Return>;
    /** Modifies the rule selector. */
    setMediaText(params: CSS.setMediaText_Parameters): Promise<CSS.setMediaText_Return>;
    /** Creates a new special "via-inspector" stylesheet in the frame with given <code>frameId</code>. */
    createStyleSheet(params: CSS.createStyleSheet_Parameters): Promise<CSS.createStyleSheet_Return>;
    /** Inserts a new rule with the given <code>ruleText</code> in a stylesheet with given <code>styleSheetId</code>, at the position specified by <code>location</code>. */
    addRule(params: CSS.addRule_Parameters): Promise<CSS.addRule_Return>;
    /** Ensures that the given node will have specified pseudo-classes whenever its style is computed by the browser. */
    forcePseudoState(params: CSS.forcePseudoState_Parameters): Promise<void>;
    /** Returns all media queries parsed by the rendering engine. */
    getMediaQueries(): Promise<CSS.getMediaQueries_Return>;
    /** Find a rule with the given active property for the given node and set the new value for this property */
    setEffectivePropertyValueForNode(params: CSS.setEffectivePropertyValueForNode_Parameters): Promise<void>;
    getBackgroundColors(params: CSS.getBackgroundColors_Parameters): Promise<CSS.getBackgroundColors_Return>;
    /** Fires whenever a MediaQuery result changes (for example, after a browser window has been resized.) The current implementation considers only viewport-dependent media features. */
    mediaQueryResultChanged: CSS.mediaQueryResultChanged_Handler;
    /** Fired whenever a stylesheet is changed as a result of the client operation. */
    styleSheetChanged: CSS.styleSheetChanged_Handler;
    /** Fired whenever an active document stylesheet is added. */
    styleSheetAdded: CSS.styleSheetAdded_Handler;
    /** Fired whenever an active document stylesheet is removed. */
    styleSheetRemoved: CSS.styleSheetRemoved_Handler;
    layoutEditorChange: CSS.layoutEditorChange_Handler;
}
export declare namespace CSS {
    type StyleSheetId = string;
    /** Stylesheet type: "injected" for stylesheets injected via extension, "user-agent" for user-agent stylesheets, "inspector" for stylesheets created by the inspector (i.e. those holding the "via inspector" rules), "regular" for regular stylesheets. */
    type StyleSheetOrigin = "injected" | "user-agent" | "inspector" | "regular";
    /** CSS rule collection for a single pseudo style. */
    interface PseudoElementMatches {
        /** Pseudo element type. */
        pseudoType: DOM.PseudoType;
        /** Matches of CSS rules applicable to the pseudo style. */
        matches: RuleMatch[];
    }
    /** Inherited CSS rule collection from ancestor node. */
    interface InheritedStyleEntry {
        /** The ancestor node's inline style, if any, in the style inheritance chain. */
        inlineStyle?: CSSStyle;
        /** Matches of CSS rules matching the ancestor node in the style inheritance chain. */
        matchedCSSRules: RuleMatch[];
    }
    /** Match data for a CSS rule. */
    interface RuleMatch {
        /** CSS rule in the match. */
        rule: CSSRule;
        /** Matching selector indices in the rule's selectorList selectors (0-based). */
        matchingSelectors: number[];
    }
    /** Data for a simple selector (these are delimited by commas in a selector list). */
    interface Value {
        /** Value text. */
        text: string;
        /** Value range in the underlying resource (if available). */
        range?: SourceRange;
    }
    /** Selector list data. */
    interface SelectorList {
        /** Selectors in the list. */
        selectors: Value[];
        /** Rule selector text. */
        text: string;
    }
    /** CSS stylesheet metainformation. */
    interface CSSStyleSheetHeader {
        /** The stylesheet identifier. */
        styleSheetId: StyleSheetId;
        /** Owner frame identifier. */
        frameId: Page.FrameId;
        /** Stylesheet resource URL. */
        sourceURL: string;
        /** URL of source map associated with the stylesheet (if any). */
        sourceMapURL?: string;
        /** Stylesheet origin. */
        origin: StyleSheetOrigin;
        /** Stylesheet title. */
        title: string;
        /** The backend id for the owner node of the stylesheet. */
        ownerNode?: DOM.BackendNodeId;
        /** Denotes whether the stylesheet is disabled. */
        disabled: boolean;
        /** Whether the sourceURL field value comes from the sourceURL comment. */
        hasSourceURL?: boolean;
        /** Whether this stylesheet is created for STYLE tag by parser. This flag is not set for document.written STYLE tags. */
        isInline: boolean;
        /** Line offset of the stylesheet within the resource (zero based). */
        startLine: number;
        /** Column offset of the stylesheet within the resource (zero based). */
        startColumn: number;
    }
    /** CSS rule representation. */
    interface CSSRule {
        /** The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from. */
        styleSheetId?: StyleSheetId;
        /** Rule selector data. */
        selectorList: SelectorList;
        /** Parent stylesheet's origin. */
        origin: StyleSheetOrigin;
        /** Associated style declaration. */
        style: CSSStyle;
        /** Media list array (for rules involving media queries). The array enumerates media queries starting with the innermost one, going outwards. */
        media?: CSSMedia[];
    }
    /** Text range within a resource. All numbers are zero-based. */
    interface SourceRange {
        /** Start line of range. */
        startLine: number;
        /** Start column of range (inclusive). */
        startColumn: number;
        /** End line of range */
        endLine: number;
        /** End column of range (exclusive). */
        endColumn: number;
    }
    interface ShorthandEntry {
        /** Shorthand name. */
        name: string;
        /** Shorthand value. */
        value: string;
        /** Whether the property has "!important" annotation (implies <code>false</code> if absent). */
        important?: boolean;
    }
    interface CSSComputedStyleProperty {
        /** Computed style property name. */
        name: string;
        /** Computed style property value. */
        value: string;
    }
    /** CSS style representation. */
    interface CSSStyle {
        /** The css style sheet identifier (absent for user agent stylesheet and user-specified stylesheet rules) this rule came from. */
        styleSheetId?: StyleSheetId;
        /** CSS properties in the style. */
        cssProperties: CSSProperty[];
        /** Computed values for all shorthands found in the style. */
        shorthandEntries: ShorthandEntry[];
        /** Style declaration text (if available). */
        cssText?: string;
        /** Style declaration range in the enclosing stylesheet (if available). */
        range?: SourceRange;
    }
    /** CSS property declaration data. */
    interface CSSProperty {
        /** The property name. */
        name: string;
        /** The property value. */
        value: string;
        /** Whether the property has "!important" annotation (implies <code>false</code> if absent). */
        important?: boolean;
        /** Whether the property is implicit (implies <code>false</code> if absent). */
        implicit?: boolean;
        /** The full property text as specified in the style. */
        text?: string;
        /** Whether the property is understood by the browser (implies <code>true</code> if absent). */
        parsedOk?: boolean;
        /** Whether the property is disabled by the user (present for source-based properties only). */
        disabled?: boolean;
        /** The entire property range in the enclosing style declaration (if available). */
        range?: SourceRange;
    }
    /** CSS media rule descriptor. */
    interface CSSMedia {
        /** Media query text. */
        text: string;
        /** Source of the media query: "mediaRule" if specified by a @media rule, "importRule" if specified by an @import rule, "linkedSheet" if specified by a "media" attribute in a linked stylesheet's LINK tag, "inlineSheet" if specified by a "media" attribute in an inline stylesheet's STYLE tag. */
        source: "mediaRule" | "importRule" | "linkedSheet" | "inlineSheet";
        /** URL of the document containing the media query description. */
        sourceURL?: string;
        /** The associated rule (@media or @import) header range in the enclosing stylesheet (if available). */
        range?: SourceRange;
        /** Identifier of the stylesheet containing this object (if exists). */
        parentStyleSheetId?: StyleSheetId;
        /** Array of media queries. */
        mediaList?: MediaQuery[];
    }
    /** Media query descriptor. */
    interface MediaQuery {
        /** Array of media query expressions. */
        expressions: MediaQueryExpression[];
        /** Whether the media query condition is satisfied. */
        active: boolean;
    }
    /** Media query expression descriptor. */
    interface MediaQueryExpression {
        /** Media query expression value. */
        value: number;
        /** Media query expression units. */
        unit: string;
        /** Media query expression feature. */
        feature: string;
        /** The associated range of the value text in the enclosing stylesheet (if available). */
        valueRange?: SourceRange;
        /** Computed length of media query expression (if applicable). */
        computedLength?: number;
    }
    /** Information about amount of glyphs that were rendered with given font. */
    interface PlatformFontUsage {
        /** Font's family name reported by platform. */
        familyName: string;
        /** Amount of glyphs that were rendered with this font. */
        glyphCount: number;
    }
    /** CSS keyframes rule representation. */
    interface CSSKeyframesRule {
        /** Animation name. */
        animationName: Value;
        /** List of keyframes. */
        keyframes: CSSKeyframeRule[];
    }
    /** CSS keyframe rule representation. */
    interface CSSKeyframeRule {
        /** Associated key text. */
        keyText: Value;
        /** Associated style declaration. */
        style: CSSStyle;
    }
    type mediaQueryResultChanged_Handler = () => void;
    type styleSheetChanged_Parameters = {
        styleSheetId: StyleSheetId;
    };
    type styleSheetChanged_Handler = (params: styleSheetChanged_Parameters) => void;
    type styleSheetAdded_Parameters = {
        /** Added stylesheet metainfo. */
        header: CSSStyleSheetHeader;
    };
    type styleSheetAdded_Handler = (params: styleSheetAdded_Parameters) => void;
    type styleSheetRemoved_Parameters = {
        /** Identifier of the removed stylesheet. */
        styleSheetId: StyleSheetId;
    };
    type styleSheetRemoved_Handler = (params: styleSheetRemoved_Parameters) => void;
    type layoutEditorChange_Parameters = {
        /** Identifier of the stylesheet where the modification occurred. */
        styleSheetId: StyleSheetId;
        /** Range where the modification occurred. */
        changeRange: SourceRange;
    };
    type layoutEditorChange_Handler = (params: layoutEditorChange_Parameters) => void;
    type getMatchedStylesForNode_Parameters = {
        nodeId: DOM.NodeId;
    };
    type getMatchedStylesForNode_Return = {
        /** Inline style for the specified DOM node. */
        inlineStyle?: CSSStyle;
        /** Attribute-defined element style (e.g. resulting from "width=20 height=100%"). */
        attributesStyle?: CSSStyle;
        /** CSS rules matching this node, from all applicable stylesheets. */
        matchedCSSRules?: RuleMatch[];
        /** Pseudo style matches for this node. */
        pseudoElements?: PseudoElementMatches[];
        /** A chain of inherited styles (from the immediate node parent up to the DOM tree root). */
        inherited?: InheritedStyleEntry[];
    };
    type getInlineStylesForNode_Parameters = {
        nodeId: DOM.NodeId;
    };
    type getInlineStylesForNode_Return = {
        /** Inline style for the specified DOM node. */
        inlineStyle?: CSSStyle;
        /** Attribute-defined element style (e.g. resulting from "width=20 height=100%"). */
        attributesStyle?: CSSStyle;
    };
    type getComputedStyleForNode_Parameters = {
        nodeId: DOM.NodeId;
    };
    type getComputedStyleForNode_Return = {
        /** Computed style for the specified DOM node. */
        computedStyle: CSSComputedStyleProperty[];
    };
    type getPlatformFontsForNode_Parameters = {
        nodeId: DOM.NodeId;
    };
    type getPlatformFontsForNode_Return = {
        /** Usage statistics for every employed platform font. */
        fonts: PlatformFontUsage[];
    };
    type getCSSAnimationsForNode_Parameters = {
        nodeId: DOM.NodeId;
    };
    type getCSSAnimationsForNode_Return = {
        /** A list of CSS keyframed animations matching this node. */
        cssKeyframesRules?: CSSKeyframesRule[];
    };
    type getStyleSheetText_Parameters = {
        styleSheetId: StyleSheetId;
    };
    type getStyleSheetText_Return = {
        /** The stylesheet text. */
        text: string;
    };
    type setStyleSheetText_Parameters = {
        styleSheetId: StyleSheetId;
        text: string;
    };
    type setStyleSheetText_Return = {
        /** URL of source map associated with script (if any). */
        sourceMapURL?: string;
    };
    type setRuleSelector_Parameters = {
        styleSheetId: StyleSheetId;
        range: SourceRange;
        selector: string;
    };
    type setRuleSelector_Return = {
        /** The resulting selector list after modification. */
        selectorList: SelectorList;
    };
    type setStyleText_Parameters = {
        styleSheetId: StyleSheetId;
        range: SourceRange;
        text: string;
    };
    type setStyleText_Return = {
        /** The resulting style after the selector modification. */
        style: CSSStyle;
    };
    type setMediaText_Parameters = {
        styleSheetId: StyleSheetId;
        range: SourceRange;
        text: string;
    };
    type setMediaText_Return = {
        /** The resulting CSS media rule after modification. */
        media: CSSMedia;
    };
    type createStyleSheet_Parameters = {
        /** Identifier of the frame where "via-inspector" stylesheet should be created. */
        frameId: Page.FrameId;
    };
    type createStyleSheet_Return = {
        /** Identifier of the created "via-inspector" stylesheet. */
        styleSheetId: StyleSheetId;
    };
    type addRule_Parameters = {
        /** The css style sheet identifier where a new rule should be inserted. */
        styleSheetId: StyleSheetId;
        /** The text of a new rule. */
        ruleText: string;
        /** Text position of a new rule in the target style sheet. */
        location: SourceRange;
    };
    type addRule_Return = {
        /** The newly created rule. */
        rule: CSSRule;
    };
    type forcePseudoState_Parameters = {
        /** The element id for which to force the pseudo state. */
        nodeId: DOM.NodeId;
        /** Element pseudo classes to force when computing the element's style. */
        forcedPseudoClasses: ("active" | "focus" | "hover" | "visited")[];
    };
    type getMediaQueries_Return = {
        medias: CSSMedia[];
    };
    type setEffectivePropertyValueForNode_Parameters = {
        /** The element id for which to set property. */
        nodeId: DOM.NodeId;
        propertyName: string;
        value: string;
    };
    type getBackgroundColors_Parameters = {
        /** Id of the node to get background colors for. */
        nodeId: DOM.NodeId;
    };
    type getBackgroundColors_Return = {
        /** The range of background colors behind this element, if it contains any visible text. If no visible text is present, this will be undefined. In the case of a flat background color, this will consist of simply that color. In the case of a gradient, this will consist of each of the color stops. For anything more complicated, this will be an empty array. Images will be ignored (as if the image had failed to load). */
        backgroundColors?: string[];
    };
}
/** Input/Output operations for streams produced by DevTools. */
export declare class IO {
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Read a chunk of the stream */
    read(params: IO.read_Parameters): Promise<IO.read_Return>;
    /** Close the stream, discard any temporary backing storage. */
    close(params: IO.close_Parameters): Promise<void>;
}
export declare namespace IO {
    type StreamHandle = string;
    type read_Parameters = {
        /** Handle of the stream to read. */
        handle: StreamHandle;
        /** Seek to the specified offset before reading (if not specificed, proceed with offset following the last read). */
        offset?: number;
        /** Maximum number of bytes to read (left upon the agent discretion if not specified). */
        size?: number;
    };
    type read_Return = {
        /** Data that were read. */
        data: string;
        /** Set if the end-of-file condition occured while reading. */
        eof: boolean;
    };
    type close_Parameters = {
        /** Handle of the stream to close. */
        handle: StreamHandle;
    };
}
/** Timeline domain is deprecated. Please use Tracing instead. */
export declare class Timeline {
    private _eventRecorded;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Deprecated. */
    enable(): Promise<void>;
    /** Deprecated. */
    disable(): Promise<void>;
    /** Deprecated. */
    start(params: Timeline.start_Parameters): Promise<void>;
    /** Deprecated. */
    stop(): Promise<void>;
    /** Deprecated. */
    eventRecorded: Timeline.eventRecorded_Handler;
}
export declare namespace Timeline {
    /** Timeline record contains information about the recorded activity. */
    interface TimelineEvent {
        /** Event type. */
        type: string;
        /** Event data. */
        data: any;
        /** Start time. */
        startTime: number;
        /** End time. */
        endTime?: number;
        /** Nested records. */
        children?: TimelineEvent[];
        /** If present, identifies the thread that produced the event. */
        thread?: string;
        /** Stack trace. */
        stackTrace?: Console.StackTrace;
        /** Unique identifier of the frame within the page that the event relates to. */
        frameId?: string;
    }
    type eventRecorded_Parameters = {
        /** Timeline event record data. */
        record: TimelineEvent;
    };
    type eventRecorded_Handler = (params: eventRecorded_Parameters) => void;
    type start_Parameters = {
        /** Samples JavaScript stack traces up to <code>maxCallStackDepth</code>, defaults to 5. */
        maxCallStackDepth?: number;
        /** Whether instrumentation events should be buffered and returned upon <code>stop</code> call. */
        bufferEvents?: boolean;
        /** Coma separated event types to issue although bufferEvents is set. */
        liveEvents?: string;
        /** Whether counters data should be included into timeline events. */
        includeCounters?: boolean;
        /** Whether events from GPU process should be collected. */
        includeGPUEvents?: boolean;
    };
}
/** Debugger domain exposes JavaScript debugging capabilities. It allows setting and removing breakpoints, stepping through execution, exploring stack traces, etc. */
export declare class Debugger {
    private _globalObjectCleared;
    private _scriptParsed;
    private _scriptFailedToParse;
    private _breakpointResolved;
    private _paused;
    private _resumed;
    private _promiseUpdated;
    private _asyncOperationStarted;
    private _asyncOperationCompleted;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received. */
    enable(): Promise<void>;
    /** Disables debugger for given page. */
    disable(): Promise<void>;
    /** Activates / deactivates all breakpoints on the page. */
    setBreakpointsActive(params: Debugger.setBreakpointsActive_Parameters): Promise<void>;
    /** Makes page not interrupt on any pauses (breakpoint, exception, dom exception etc). */
    setSkipAllPauses(params: Debugger.setSkipAllPauses_Parameters): Promise<void>;
    /** Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in <code>locations</code> property. Further matching script parsing will result in subsequent <code>breakpointResolved</code> events issued. This logical breakpoint will survive page reloads. */
    setBreakpointByUrl(params: Debugger.setBreakpointByUrl_Parameters): Promise<Debugger.setBreakpointByUrl_Return>;
    /** Sets JavaScript breakpoint at a given location. */
    setBreakpoint(params: Debugger.setBreakpoint_Parameters): Promise<Debugger.setBreakpoint_Return>;
    /** Removes JavaScript breakpoint. */
    removeBreakpoint(params: Debugger.removeBreakpoint_Parameters): Promise<void>;
    /** Continues execution until specific location is reached. */
    continueToLocation(params: Debugger.continueToLocation_Parameters): Promise<void>;
    /** Steps over the statement. */
    stepOver(): Promise<void>;
    /** Steps into the function call. */
    stepInto(): Promise<void>;
    /** Steps out of the function call. */
    stepOut(): Promise<void>;
    /** Stops on the next JavaScript statement. */
    pause(): Promise<void>;
    /** Resumes JavaScript execution. */
    resume(): Promise<void>;
    /** Steps into the first async operation handler that was scheduled by or after the current statement. */
    stepIntoAsync(): Promise<void>;
    /** Searches for given string in script content. */
    searchInContent(params: Debugger.searchInContent_Parameters): Promise<Debugger.searchInContent_Return>;
    /** Always returns true. */
    canSetScriptSource(): Promise<Debugger.canSetScriptSource_Return>;
    /** Edits JavaScript source live. */
    setScriptSource(params: Debugger.setScriptSource_Parameters): Promise<Debugger.setScriptSource_Return>;
    /** Restarts particular call frame from the beginning. */
    restartFrame(params: Debugger.restartFrame_Parameters): Promise<Debugger.restartFrame_Return>;
    /** Returns source for the script with given id. */
    getScriptSource(params: Debugger.getScriptSource_Parameters): Promise<Debugger.getScriptSource_Return>;
    /** Returns detailed information on given function. */
    getFunctionDetails(params: Debugger.getFunctionDetails_Parameters): Promise<Debugger.getFunctionDetails_Return>;
    /** Returns detailed information on given generator object. */
    getGeneratorObjectDetails(params: Debugger.getGeneratorObjectDetails_Parameters): Promise<Debugger.getGeneratorObjectDetails_Return>;
    /** Returns entries of given collection. */
    getCollectionEntries(params: Debugger.getCollectionEntries_Parameters): Promise<Debugger.getCollectionEntries_Return>;
    /** Defines pause on exceptions state. Can be set to stop on all exceptions, uncaught exceptions or no exceptions. Initial pause on exceptions state is <code>none</code>. */
    setPauseOnExceptions(params: Debugger.setPauseOnExceptions_Parameters): Promise<void>;
    /** Evaluates expression on a given call frame. */
    evaluateOnCallFrame(params: Debugger.evaluateOnCallFrame_Parameters): Promise<Debugger.evaluateOnCallFrame_Return>;
    /** Compiles expression. */
    compileScript(params: Debugger.compileScript_Parameters): Promise<Debugger.compileScript_Return>;
    /** Runs script with given id in a given context. */
    runScript(params: Debugger.runScript_Parameters): Promise<Debugger.runScript_Return>;
    /** Changes value of variable in a callframe or a closure. Either callframe or function must be specified. Object-based scopes are not supported and must be mutated manually. */
    setVariableValue(params: Debugger.setVariableValue_Parameters): Promise<void>;
    /** Lists all positions where step-in is possible for a current statement in a specified call frame */
    getStepInPositions(params: Debugger.getStepInPositions_Parameters): Promise<Debugger.getStepInPositions_Return>;
    /** Returns call stack including variables changed since VM was paused. VM must be paused. */
    getBacktrace(): Promise<Debugger.getBacktrace_Return>;
    /** Makes backend skip steps in the sources with names matching given pattern. VM will try leave blacklisted scripts by performing 'step in' several times, finally resorting to 'step out' if unsuccessful. */
    skipStackFrames(params: Debugger.skipStackFrames_Parameters): Promise<void>;
    /** Enables or disables async call stacks tracking. */
    setAsyncCallStackDepth(params: Debugger.setAsyncCallStackDepth_Parameters): Promise<void>;
    /** Enables promise tracking, information about <code>Promise</code>s created or updated will now be stored on the backend. */
    enablePromiseTracker(params: Debugger.enablePromiseTracker_Parameters): Promise<void>;
    /** Disables promise tracking. */
    disablePromiseTracker(): Promise<void>;
    /** Returns <code>Promise</code> with specified ID. */
    getPromiseById(params: Debugger.getPromiseById_Parameters): Promise<Debugger.getPromiseById_Return>;
    /** Fires pending <code>asyncOperationStarted</code> events (if any), as if a debugger stepping session has just been started. */
    flushAsyncOperationEvents(): Promise<void>;
    /** Sets breakpoint on AsyncOperation callback handler. */
    setAsyncOperationBreakpoint(params: Debugger.setAsyncOperationBreakpoint_Parameters): Promise<void>;
    /** Removes AsyncOperation breakpoint. */
    removeAsyncOperationBreakpoint(params: Debugger.removeAsyncOperationBreakpoint_Parameters): Promise<void>;
    /** Called when global has been cleared and debugger client should reset its state. Happens upon navigation or reload. */
    globalObjectCleared: Debugger.globalObjectCleared_Handler;
    /** Fired when virtual machine parses script. This event is also fired for all known and uncollected scripts upon enabling debugger. */
    scriptParsed: Debugger.scriptParsed_Handler;
    /** Fired when virtual machine fails to parse the script. */
    scriptFailedToParse: Debugger.scriptFailedToParse_Handler;
    /** Fired when breakpoint is resolved to an actual script and location. */
    breakpointResolved: Debugger.breakpointResolved_Handler;
    /** Fired when the virtual machine stopped on breakpoint or exception or any other stop criteria. */
    paused: Debugger.paused_Handler;
    /** Fired when the virtual machine resumed execution. */
    resumed: Debugger.resumed_Handler;
    /** Fired when a <code>Promise</code> is created, updated or garbage collected. */
    promiseUpdated: Debugger.promiseUpdated_Handler;
    /** Fired when an async operation is scheduled (while in a debugger stepping session). */
    asyncOperationStarted: Debugger.asyncOperationStarted_Handler;
    /** Fired when an async operation is completed (while in a debugger stepping session). */
    asyncOperationCompleted: Debugger.asyncOperationCompleted_Handler;
}
export declare namespace Debugger {
    /** Breakpoint identifier. */
    type BreakpointId = string;
    /** Unique script identifier. */
    type ScriptId = string;
    /** Call frame identifier. */
    type CallFrameId = string;
    /** Location in the source code. */
    interface Location {
        /** Script identifier as reported in the <code>Debugger.scriptParsed</code>. */
        scriptId: ScriptId;
        /** Line number in the script (0-based). */
        lineNumber: number;
        /** Column number in the script (0-based). */
        columnNumber?: number;
    }
    /** Information about the function. */
    interface FunctionDetails {
        /** Location of the function, none for native functions. */
        location?: Location;
        /** Name of the function. */
        functionName: string;
        /** Whether this is a generator function. */
        isGenerator: boolean;
        /** Scope chain for this closure. */
        scopeChain?: Scope[];
    }
    /** Information about the generator object. */
    interface GeneratorObjectDetails {
        /** Generator function. */
        function: Runtime.RemoteObject;
        /** Name of the generator function. */
        functionName: string;
        /** Current generator object status. */
        status: "running" | "suspended" | "closed";
        /** If suspended, location where generator function was suspended (e.g. location of the last 'yield'). Otherwise, location of the generator function. */
        location?: Location;
    }
    /** Collection entry. */
    interface CollectionEntry {
        /** Entry key of a map-like collection, otherwise not provided. */
        key?: Runtime.RemoteObject;
        /** Entry value. */
        value: Runtime.RemoteObject;
    }
    /** JavaScript call frame. Array of call frames form the call stack. */
    interface CallFrame {
        /** Call frame identifier. This identifier is only valid while the virtual machine is paused. */
        callFrameId: CallFrameId;
        /** Name of the JavaScript function called on this call frame. */
        functionName: string;
        /** Location in the source code. */
        functionLocation?: Location;
        /** Location in the source code. */
        location: Location;
        /** Scope chain for this call frame. */
        scopeChain: Scope[];
        /** <code>this</code> object for this call frame. */
        this: Runtime.RemoteObject;
        /** The value being returned, if the function is at return point. */
        returnValue?: Runtime.RemoteObject;
    }
    /** JavaScript call stack, including async stack traces. */
    interface StackTrace {
        /** Call frames of the stack trace. */
        callFrames: CallFrame[];
        /** String label of this stack trace. For async traces this may be a name of the function that initiated the async call. */
        description?: string;
        /** Async stack trace, if any. */
        asyncStackTrace?: StackTrace;
    }
    /** Scope description. */
    interface Scope {
        /** Scope type. */
        type: "global" | "local" | "with" | "closure" | "catch" | "block" | "script";
        /** Object representing the scope. For <code>global</code> and <code>with</code> scopes it represents the actual object; for the rest of the scopes, it is artificial transient object enumerating scope variables as its properties. */
        object: Runtime.RemoteObject;
        name?: string;
    }
    /** Detailed information on exception (or error) that was thrown during script compilation or execution. */
    interface ExceptionDetails {
        /** Exception text. */
        text: string;
        /** URL of the message origin. */
        url?: string;
        /** Script ID of the message origin. */
        scriptId?: string;
        /** Line number in the resource that generated this message. */
        line?: number;
        /** Column number in the resource that generated this message. */
        column?: number;
        /** JavaScript stack trace for assertions and error messages. */
        stackTrace?: Console.StackTrace;
    }
    /** Error data for setScriptSource command. compileError is a case type for uncompilable script source error. */
    interface SetScriptSourceError {
        compileError?: {
            message: string;
            lineNumber: number;
            columnNumber: number;
        };
    }
    /** Information about the promise. All fields but id are optional and if present they reflect the new state of the property on the promise with given id. */
    interface PromiseDetails {
        /** Unique id of the promise. */
        id: number;
        /** Status of the promise. */
        status?: "pending" | "resolved" | "rejected";
        /** Id of the parent promise. */
        parentId?: number;
        /** Top call frame on promise creation. */
        callFrame?: Console.CallFrame;
        /** Creation time of the promise. */
        creationTime?: number;
        /** Settlement time of the promise. */
        settlementTime?: number;
        /** JavaScript stack trace on promise creation. */
        creationStack?: Console.StackTrace;
        /** JavaScript asynchronous stack trace on promise creation, if available. */
        asyncCreationStack?: Console.AsyncStackTrace;
        /** JavaScript stack trace on promise settlement. */
        settlementStack?: Console.StackTrace;
        /** JavaScript asynchronous stack trace on promise settlement, if available. */
        asyncSettlementStack?: Console.AsyncStackTrace;
    }
    /** Information about the async operation. */
    interface AsyncOperation {
        /** Unique id of the async operation. */
        id: number;
        /** String description of the async operation. */
        description: string;
        /** Stack trace where async operation was scheduled. */
        stackTrace?: Console.StackTrace;
        /** Asynchronous stack trace where async operation was scheduled, if available. */
        asyncStackTrace?: Console.AsyncStackTrace;
    }
    /** Search match for resource. */
    interface SearchMatch {
        /** Line number in resource content. */
        lineNumber: number;
        /** Line with match content. */
        lineContent: string;
    }
    type globalObjectCleared_Handler = () => void;
    type scriptParsed_Parameters = {
        /** Identifier of the script parsed. */
        scriptId: ScriptId;
        /** URL or name of the script parsed (if any). */
        url: string;
        /** Line offset of the script within the resource with given URL (for script tags). */
        startLine: number;
        /** Column offset of the script within the resource with given URL. */
        startColumn: number;
        /** Last line of the script. */
        endLine: number;
        /** Length of the last line of the script. */
        endColumn: number;
        /** Specifies script creation context. */
        executionContextId: Runtime.ExecutionContextId;
        /** Determines whether this script is a user extension script. */
        isContentScript?: boolean;
        /** Determines whether this script is an internal script. */
        isInternalScript?: boolean;
        /** True, if this script is generated as a result of the live edit operation. */
        isLiveEdit?: boolean;
        /** URL of source map associated with script (if any). */
        sourceMapURL?: string;
        /** True, if this script has sourceURL. */
        hasSourceURL?: boolean;
    };
    type scriptParsed_Handler = (params: scriptParsed_Parameters) => void;
    type scriptFailedToParse_Parameters = {
        /** Identifier of the script parsed. */
        scriptId: ScriptId;
        /** URL or name of the script parsed (if any). */
        url: string;
        /** Line offset of the script within the resource with given URL (for script tags). */
        startLine: number;
        /** Column offset of the script within the resource with given URL. */
        startColumn: number;
        /** Last line of the script. */
        endLine: number;
        /** Length of the last line of the script. */
        endColumn: number;
        /** Specifies script creation context. */
        executionContextId: Runtime.ExecutionContextId;
        /** Determines whether this script is a user extension script. */
        isContentScript?: boolean;
        /** Determines whether this script is an internal script. */
        isInternalScript?: boolean;
        /** URL of source map associated with script (if any). */
        sourceMapURL?: string;
        /** True, if this script has sourceURL. */
        hasSourceURL?: boolean;
    };
    type scriptFailedToParse_Handler = (params: scriptFailedToParse_Parameters) => void;
    type breakpointResolved_Parameters = {
        /** Breakpoint unique identifier. */
        breakpointId: BreakpointId;
        /** Actual breakpoint location. */
        location: Location;
    };
    type breakpointResolved_Handler = (params: breakpointResolved_Parameters) => void;
    type paused_Parameters = {
        /** Call stack the virtual machine stopped on. */
        callFrames: CallFrame[];
        /** Pause reason. */
        reason: "XHR" | "DOM" | "EventListener" | "exception" | "assert" | "CSPViolation" | "debugCommand" | "promiseRejection" | "AsyncOperation" | "other";
        /** Object containing break-specific auxiliary properties. */
        data?: any;
        /** Hit breakpoints IDs */
        hitBreakpoints?: string[];
        /** Async stack trace, if any. */
        asyncStackTrace?: StackTrace;
    };
    type paused_Handler = (params: paused_Parameters) => void;
    type resumed_Handler = () => void;
    type promiseUpdated_Parameters = {
        /** Type of the event. */
        eventType: "new" | "update" | "gc";
        /** Information about the updated <code>Promise</code>. */
        promise: PromiseDetails;
    };
    type promiseUpdated_Handler = (params: promiseUpdated_Parameters) => void;
    type asyncOperationStarted_Parameters = {
        /** Information about the async operation. */
        operation: AsyncOperation;
    };
    type asyncOperationStarted_Handler = (params: asyncOperationStarted_Parameters) => void;
    type asyncOperationCompleted_Parameters = {
        /** ID of the async operation that was completed. */
        id: number;
    };
    type asyncOperationCompleted_Handler = (params: asyncOperationCompleted_Parameters) => void;
    type setBreakpointsActive_Parameters = {
        /** New value for breakpoints active state. */
        active: boolean;
    };
    type setSkipAllPauses_Parameters = {
        /** New value for skip pauses state. */
        skipped: boolean;
    };
    type setBreakpointByUrl_Parameters = {
        /** Line number to set breakpoint at. */
        lineNumber: number;
        /** URL of the resources to set breakpoint on. */
        url?: string;
        /** Regex pattern for the URLs of the resources to set breakpoints on. Either <code>url</code> or <code>urlRegex</code> must be specified. */
        urlRegex?: string;
        /** Offset in the line to set breakpoint at. */
        columnNumber?: number;
        /** Expression to use as a breakpoint condition. When specified, debugger will only stop on the breakpoint if this expression evaluates to true. */
        condition?: string;
    };
    type setBreakpointByUrl_Return = {
        /** Id of the created breakpoint for further reference. */
        breakpointId: BreakpointId;
        /** List of the locations this breakpoint resolved into upon addition. */
        locations: Location[];
    };
    type setBreakpoint_Parameters = {
        /** Location to set breakpoint in. */
        location: Location;
        /** Expression to use as a breakpoint condition. When specified, debugger will only stop on the breakpoint if this expression evaluates to true. */
        condition?: string;
    };
    type setBreakpoint_Return = {
        /** Id of the created breakpoint for further reference. */
        breakpointId: BreakpointId;
        /** Location this breakpoint resolved into. */
        actualLocation: Location;
    };
    type removeBreakpoint_Parameters = {
        breakpointId: BreakpointId;
    };
    type continueToLocation_Parameters = {
        /** Location to continue to. */
        location: Location;
        /** Allows breakpoints at the intemediate positions inside statements. */
        interstatementLocation?: boolean;
    };
    type searchInContent_Parameters = {
        /** Id of the script to search in. */
        scriptId: ScriptId;
        /** String to search for. */
        query: string;
        /** If true, search is case sensitive. */
        caseSensitive?: boolean;
        /** If true, treats string parameter as regex. */
        isRegex?: boolean;
    };
    type searchInContent_Return = {
        /** List of search matches. */
        result: SearchMatch[];
    };
    type canSetScriptSource_Return = {
        /** True if <code>setScriptSource</code> is supported. */
        result: boolean;
    };
    type setScriptSource_Parameters = {
        /** Id of the script to edit. */
        scriptId: ScriptId;
        /** New content of the script. */
        scriptSource: string;
        /**  If true the change will not actually be applied. Preview mode may be used to get result description without actually modifying the code. */
        preview?: boolean;
    };
    type setScriptSource_Return = {
        /** New stack trace in case editing has happened while VM was stopped. */
        callFrames?: CallFrame[];
        /** Whether current call stack  was modified after applying the changes. */
        stackChanged?: boolean;
        /** Async stack trace, if any. */
        asyncStackTrace?: StackTrace;
    };
    type restartFrame_Parameters = {
        /** Call frame identifier to evaluate on. */
        callFrameId: CallFrameId;
    };
    type restartFrame_Return = {
        /** New stack trace. */
        callFrames: CallFrame[];
        /** Async stack trace, if any. */
        asyncStackTrace?: StackTrace;
    };
    type getScriptSource_Parameters = {
        /** Id of the script to get source for. */
        scriptId: ScriptId;
    };
    type getScriptSource_Return = {
        /** Script source. */
        scriptSource: string;
    };
    type getFunctionDetails_Parameters = {
        /** Id of the function to get details for. */
        functionId: Runtime.RemoteObjectId;
    };
    type getFunctionDetails_Return = {
        /** Information about the function. */
        details: FunctionDetails;
    };
    type getGeneratorObjectDetails_Parameters = {
        /** Id of the generator object to get details for. */
        objectId: Runtime.RemoteObjectId;
    };
    type getGeneratorObjectDetails_Return = {
        /** Information about the generator object. */
        details: GeneratorObjectDetails;
    };
    type getCollectionEntries_Parameters = {
        /** Id of the collection to get entries for. */
        objectId: Runtime.RemoteObjectId;
    };
    type getCollectionEntries_Return = {
        /** Array of collection entries. */
        entries: CollectionEntry[];
    };
    type setPauseOnExceptions_Parameters = {
        /** Pause on exceptions mode. */
        state: "none" | "uncaught" | "all";
    };
    type evaluateOnCallFrame_Parameters = {
        /** Call frame identifier to evaluate on. */
        callFrameId: CallFrameId;
        /** Expression to evaluate. */
        expression: string;
        /** String object group name to put result into (allows rapid releasing resulting object handles using <code>releaseObjectGroup</code>). */
        objectGroup?: string;
        /** Specifies whether command line API should be available to the evaluated expression, defaults to false. */
        includeCommandLineAPI?: boolean;
        /** Specifies whether evaluation should stop on exceptions and mute console. Overrides setPauseOnException state. */
        doNotPauseOnExceptionsAndMuteConsole?: boolean;
        /** Whether the result is expected to be a JSON object that should be sent by value. */
        returnByValue?: boolean;
        /** Whether preview should be generated for the result. */
        generatePreview?: boolean;
    };
    type evaluateOnCallFrame_Return = {
        /** Object wrapper for the evaluation result. */
        result: Runtime.RemoteObject;
        /** True if the result was thrown during the evaluation. */
        wasThrown?: boolean;
        /** Exception details. */
        exceptionDetails?: ExceptionDetails;
    };
    type compileScript_Parameters = {
        /** Expression to compile. */
        expression: string;
        /** Source url to be set for the script. */
        sourceURL: string;
        /** Specifies whether the compiled script should be persisted. */
        persistScript: boolean;
        /** Specifies in which isolated context to perform script run. Each content script lives in an isolated context and this parameter is used to specify one of those contexts. */
        executionContextId: Runtime.ExecutionContextId;
    };
    type compileScript_Return = {
        /** Id of the script. */
        scriptId?: ScriptId;
        /** Exception details. */
        exceptionDetails?: ExceptionDetails;
    };
    type runScript_Parameters = {
        /** Id of the script to run. */
        scriptId: ScriptId;
        /** Specifies in which isolated context to perform script run. Each content script lives in an isolated context and this parameter is used to specify one of those contexts. */
        executionContextId: Runtime.ExecutionContextId;
        /** Symbolic group name that can be used to release multiple objects. */
        objectGroup?: string;
        /** Specifies whether script run should stop on exceptions and mute console. Overrides setPauseOnException state. */
        doNotPauseOnExceptionsAndMuteConsole?: boolean;
    };
    type runScript_Return = {
        /** Run result. */
        result: Runtime.RemoteObject;
        /** Exception details. */
        exceptionDetails?: ExceptionDetails;
    };
    type setVariableValue_Parameters = {
        /** 0-based number of scope as was listed in scope chain. Only 'local', 'closure' and 'catch' scope types are allowed. Other scopes could be manipulated manually. */
        scopeNumber: number;
        /** Variable name. */
        variableName: string;
        /** New variable value. */
        newValue: Runtime.CallArgument;
        /** Id of callframe that holds variable. */
        callFrameId?: CallFrameId;
        /** Object id of closure (function) that holds variable. */
        functionObjectId?: Runtime.RemoteObjectId;
    };
    type getStepInPositions_Parameters = {
        /** Id of a call frame where the current statement should be analized */
        callFrameId: CallFrameId;
    };
    type getStepInPositions_Return = {
        /** experimental */
        stepInPositions?: Location[];
    };
    type getBacktrace_Return = {
        /** Call stack the virtual machine stopped on. */
        callFrames: CallFrame[];
        /** Async stack trace, if any. */
        asyncStackTrace?: StackTrace;
    };
    type skipStackFrames_Parameters = {
        /** Regular expression defining the scripts to ignore while stepping. */
        script?: string;
        /** True, if all content scripts should be ignored. */
        skipContentScripts?: boolean;
    };
    type setAsyncCallStackDepth_Parameters = {
        /** Maximum depth of async call stacks. Setting to <code>0</code> will effectively disable collecting async call stacks (default). */
        maxDepth: number;
    };
    type enablePromiseTracker_Parameters = {
        /** Whether to capture stack traces for promise creation and settlement events (default: false). */
        captureStacks?: boolean;
    };
    type getPromiseById_Parameters = {
        promiseId: number;
        /** Symbolic group name that can be used to release multiple objects. */
        objectGroup?: string;
    };
    type getPromiseById_Return = {
        /** Object wrapper for <code>Promise</code> with specified ID, if any. */
        promise: Runtime.RemoteObject;
    };
    type setAsyncOperationBreakpoint_Parameters = {
        /** ID of the async operation to set breakpoint for. */
        operationId: number;
    };
    type removeAsyncOperationBreakpoint_Parameters = {
        /** ID of the async operation to remove breakpoint for. */
        operationId: number;
    };
}
/** DOM debugging allows setting breakpoints on particular DOM operations and events. JavaScript execution will stop on these operations as if there was a regular breakpoint set. */
export declare class DOMDebugger {
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Sets breakpoint on particular operation with DOM. */
    setDOMBreakpoint(params: DOMDebugger.setDOMBreakpoint_Parameters): Promise<void>;
    /** Removes DOM breakpoint that was set using <code>setDOMBreakpoint</code>. */
    removeDOMBreakpoint(params: DOMDebugger.removeDOMBreakpoint_Parameters): Promise<void>;
    /** Sets breakpoint on particular DOM event. */
    setEventListenerBreakpoint(params: DOMDebugger.setEventListenerBreakpoint_Parameters): Promise<void>;
    /** Removes breakpoint on particular DOM event. */
    removeEventListenerBreakpoint(params: DOMDebugger.removeEventListenerBreakpoint_Parameters): Promise<void>;
    /** Sets breakpoint on particular native event. */
    setInstrumentationBreakpoint(params: DOMDebugger.setInstrumentationBreakpoint_Parameters): Promise<void>;
    /** Removes breakpoint on particular native event. */
    removeInstrumentationBreakpoint(params: DOMDebugger.removeInstrumentationBreakpoint_Parameters): Promise<void>;
    /** Sets breakpoint on XMLHttpRequest. */
    setXHRBreakpoint(params: DOMDebugger.setXHRBreakpoint_Parameters): Promise<void>;
    /** Removes breakpoint from XMLHttpRequest. */
    removeXHRBreakpoint(params: DOMDebugger.removeXHRBreakpoint_Parameters): Promise<void>;
    /** Returns event listeners of the given object. */
    getEventListeners(params: DOMDebugger.getEventListeners_Parameters): Promise<DOMDebugger.getEventListeners_Return>;
}
export declare namespace DOMDebugger {
    /** DOM breakpoint type. */
    type DOMBreakpointType = "subtree-modified" | "attribute-modified" | "node-removed";
    /** Object event listener. */
    interface EventListener {
        /** <code>EventListener</code>'s type. */
        type: string;
        /** <code>EventListener</code>'s useCapture. */
        useCapture: boolean;
        /** Handler code location. */
        location: Debugger.Location;
        /** Event handler function value. */
        handler?: Runtime.RemoteObject;
        /** Event original handler function value. */
        originalHandler?: Runtime.RemoteObject;
    }
    type setDOMBreakpoint_Parameters = {
        /** Identifier of the node to set breakpoint on. */
        nodeId: DOM.NodeId;
        /** Type of the operation to stop upon. */
        type: DOMBreakpointType;
    };
    type removeDOMBreakpoint_Parameters = {
        /** Identifier of the node to remove breakpoint from. */
        nodeId: DOM.NodeId;
        /** Type of the breakpoint to remove. */
        type: DOMBreakpointType;
    };
    type setEventListenerBreakpoint_Parameters = {
        /** DOM Event name to stop on (any DOM event will do). */
        eventName: string;
        /** EventTarget interface name to stop on. If equal to <code>"*"</code> or not provided, will stop on any EventTarget. */
        targetName?: string;
    };
    type removeEventListenerBreakpoint_Parameters = {
        /** Event name. */
        eventName: string;
        /** EventTarget interface name. */
        targetName?: string;
    };
    type setInstrumentationBreakpoint_Parameters = {
        /** Instrumentation name to stop on. */
        eventName: string;
    };
    type removeInstrumentationBreakpoint_Parameters = {
        /** Instrumentation name to stop on. */
        eventName: string;
    };
    type setXHRBreakpoint_Parameters = {
        /** Resource URL substring. All XHRs having this substring in the URL will get stopped upon. */
        url: string;
    };
    type removeXHRBreakpoint_Parameters = {
        /** Resource URL substring. */
        url: string;
    };
    type getEventListeners_Parameters = {
        /** Identifier of the object to return listeners for. */
        objectId: Runtime.RemoteObjectId;
    };
    type getEventListeners_Return = {
        /** Array of relevant listeners. */
        listeners: EventListener[];
    };
}
export declare class Profiler {
    private _consoleProfileStarted;
    private _consoleProfileFinished;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    enable(): Promise<void>;
    disable(): Promise<void>;
    /** Changes CPU profiler sampling interval. Must be called before CPU profiles recording started. */
    setSamplingInterval(params: Profiler.setSamplingInterval_Parameters): Promise<void>;
    start(): Promise<void>;
    stop(): Promise<Profiler.stop_Return>;
    /** Sent when new profile recodring is started using console.profile() call. */
    consoleProfileStarted: Profiler.consoleProfileStarted_Handler;
    consoleProfileFinished: Profiler.consoleProfileFinished_Handler;
}
export declare namespace Profiler {
    /** CPU Profile node. Holds callsite information, execution statistics and child nodes. */
    interface CPUProfileNode {
        /** Function name. */
        functionName: string;
        /** Script identifier. */
        scriptId: Debugger.ScriptId;
        /** URL. */
        url: string;
        /** 1-based line number of the function start position. */
        lineNumber: number;
        /** 1-based column number of the function start position. */
        columnNumber: number;
        /** Number of samples where this node was on top of the call stack. */
        hitCount: number;
        /** Call UID. */
        callUID: number;
        /** Child nodes. */
        children: CPUProfileNode[];
        /** The reason of being not optimized. The function may be deoptimized or marked as don't optimize. */
        deoptReason: string;
        /** Unique id of the node. */
        id: number;
        /** An array of source position ticks. */
        positionTicks: PositionTickInfo[];
    }
    /** Profile. */
    interface CPUProfile {
        head: CPUProfileNode;
        /** Profiling start time in seconds. */
        startTime: number;
        /** Profiling end time in seconds. */
        endTime: number;
        /** Ids of samples top nodes. */
        samples?: number[];
        /** Timestamps of the samples in microseconds. */
        timestamps?: number[];
    }
    /** Specifies a number of samples attributed to a certain source position. */
    interface PositionTickInfo {
        /** Source line number (1-based). */
        line: number;
        /** Number of samples attributed to the source line. */
        ticks: number;
    }
    type consoleProfileStarted_Parameters = {
        id: string;
        /** Location of console.profile(). */
        location: Debugger.Location;
        /** Profile title passed as argument to console.profile(). */
        title?: string;
    };
    type consoleProfileStarted_Handler = (params: consoleProfileStarted_Parameters) => void;
    type consoleProfileFinished_Parameters = {
        id: string;
        /** Location of console.profileEnd(). */
        location: Debugger.Location;
        profile: CPUProfile;
        /** Profile title passed as argunet to console.profile(). */
        title?: string;
    };
    type consoleProfileFinished_Handler = (params: consoleProfileFinished_Parameters) => void;
    type setSamplingInterval_Parameters = {
        /** New sampling interval in microseconds. */
        interval: number;
    };
    type stop_Return = {
        /** Recorded profile. */
        profile: CPUProfile;
    };
}
export declare class HeapProfiler {
    private _addHeapSnapshotChunk;
    private _resetProfiles;
    private _reportHeapSnapshotProgress;
    private _lastSeenObjectId;
    private _heapStatsUpdate;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    enable(): Promise<void>;
    disable(): Promise<void>;
    startTrackingHeapObjects(params: HeapProfiler.startTrackingHeapObjects_Parameters): Promise<void>;
    stopTrackingHeapObjects(params: HeapProfiler.stopTrackingHeapObjects_Parameters): Promise<void>;
    takeHeapSnapshot(params: HeapProfiler.takeHeapSnapshot_Parameters): Promise<void>;
    collectGarbage(): Promise<void>;
    getObjectByHeapObjectId(params: HeapProfiler.getObjectByHeapObjectId_Parameters): Promise<HeapProfiler.getObjectByHeapObjectId_Return>;
    /** Enables console to refer to the node with given id via $x (see Command Line API for more details $x functions). */
    addInspectedHeapObject(params: HeapProfiler.addInspectedHeapObject_Parameters): Promise<void>;
    getHeapObjectId(params: HeapProfiler.getHeapObjectId_Parameters): Promise<HeapProfiler.getHeapObjectId_Return>;
    addHeapSnapshotChunk: HeapProfiler.addHeapSnapshotChunk_Handler;
    resetProfiles: HeapProfiler.resetProfiles_Handler;
    reportHeapSnapshotProgress: HeapProfiler.reportHeapSnapshotProgress_Handler;
    /** If heap objects tracking has been started then backend regulary sends a current value for last seen object id and corresponding timestamp. If the were changes in the heap since last event then one or more heapStatsUpdate events will be sent before a new lastSeenObjectId event. */
    lastSeenObjectId: HeapProfiler.lastSeenObjectId_Handler;
    /** If heap objects tracking has been started then backend may send update for one or more fragments */
    heapStatsUpdate: HeapProfiler.heapStatsUpdate_Handler;
}
export declare namespace HeapProfiler {
    /** Heap snapshot object id. */
    type HeapSnapshotObjectId = string;
    type addHeapSnapshotChunk_Parameters = {
        chunk: string;
    };
    type addHeapSnapshotChunk_Handler = (params: addHeapSnapshotChunk_Parameters) => void;
    type resetProfiles_Handler = () => void;
    type reportHeapSnapshotProgress_Parameters = {
        done: number;
        total: number;
        finished?: boolean;
    };
    type reportHeapSnapshotProgress_Handler = (params: reportHeapSnapshotProgress_Parameters) => void;
    type lastSeenObjectId_Parameters = {
        lastSeenObjectId: number;
        timestamp: number;
    };
    type lastSeenObjectId_Handler = (params: lastSeenObjectId_Parameters) => void;
    type heapStatsUpdate_Parameters = {
        /** An array of triplets. Each triplet describes a fragment. The first integer is the fragment index, the second integer is a total count of objects for the fragment, the third integer is a total size of the objects for the fragment. */
        statsUpdate: number[];
    };
    type heapStatsUpdate_Handler = (params: heapStatsUpdate_Parameters) => void;
    type startTrackingHeapObjects_Parameters = {
        trackAllocations?: boolean;
    };
    type stopTrackingHeapObjects_Parameters = {
        /** If true 'reportHeapSnapshotProgress' events will be generated while snapshot is being taken when the tracking is stopped. */
        reportProgress?: boolean;
    };
    type takeHeapSnapshot_Parameters = {
        /** If true 'reportHeapSnapshotProgress' events will be generated while snapshot is being taken. */
        reportProgress?: boolean;
    };
    type getObjectByHeapObjectId_Parameters = {
        objectId: HeapSnapshotObjectId;
        /** Symbolic group name that can be used to release multiple objects. */
        objectGroup?: string;
    };
    type getObjectByHeapObjectId_Return = {
        /** Evaluation result. */
        result: Runtime.RemoteObject;
    };
    type addInspectedHeapObject_Parameters = {
        /** Heap snapshot object id to be accessible by means of $x command line API. */
        heapObjectId: HeapSnapshotObjectId;
    };
    type getHeapObjectId_Parameters = {
        /** Identifier of the object to get heap object id for. */
        objectId: Runtime.RemoteObjectId;
    };
    type getHeapObjectId_Return = {
        /** Id of the heap snapshot object corresponding to the passed remote object id. */
        heapSnapshotObjectId: HeapSnapshotObjectId;
    };
}
export declare class Worker {
    private _workerCreated;
    private _workerTerminated;
    private _dispatchMessageFromWorker;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    enable(): Promise<void>;
    disable(): Promise<void>;
    sendMessageToWorker(params: Worker.sendMessageToWorker_Parameters): Promise<void>;
    connectToWorker(params: Worker.connectToWorker_Parameters): Promise<void>;
    disconnectFromWorker(params: Worker.disconnectFromWorker_Parameters): Promise<void>;
    setAutoconnectToWorkers(params: Worker.setAutoconnectToWorkers_Parameters): Promise<void>;
    workerCreated: Worker.workerCreated_Handler;
    workerTerminated: Worker.workerTerminated_Handler;
    dispatchMessageFromWorker: Worker.dispatchMessageFromWorker_Handler;
}
export declare namespace Worker {
    type workerCreated_Parameters = {
        workerId: string;
        url: string;
        inspectorConnected: boolean;
    };
    type workerCreated_Handler = (params: workerCreated_Parameters) => void;
    type workerTerminated_Parameters = {
        workerId: string;
    };
    type workerTerminated_Handler = (params: workerTerminated_Parameters) => void;
    type dispatchMessageFromWorker_Parameters = {
        workerId: string;
        message: string;
    };
    type dispatchMessageFromWorker_Handler = (params: dispatchMessageFromWorker_Parameters) => void;
    type sendMessageToWorker_Parameters = {
        workerId: string;
        message: string;
    };
    type connectToWorker_Parameters = {
        workerId: string;
    };
    type disconnectFromWorker_Parameters = {
        workerId: string;
    };
    type setAutoconnectToWorkers_Parameters = {
        value: boolean;
    };
}
export declare class ServiceWorker {
    private _workerCreated;
    private _workerTerminated;
    private _dispatchMessage;
    private _workerRegistrationUpdated;
    private _workerVersionUpdated;
    private _workerErrorReported;
    private _debugOnStartUpdated;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    enable(): Promise<void>;
    disable(): Promise<void>;
    sendMessage(params: ServiceWorker.sendMessage_Parameters): Promise<void>;
    stop(params: ServiceWorker.stop_Parameters): Promise<void>;
    unregister(params: ServiceWorker.unregister_Parameters): Promise<void>;
    updateRegistration(params: ServiceWorker.updateRegistration_Parameters): Promise<void>;
    startWorker(params: ServiceWorker.startWorker_Parameters): Promise<void>;
    stopWorker(params: ServiceWorker.stopWorker_Parameters): Promise<void>;
    inspectWorker(params: ServiceWorker.inspectWorker_Parameters): Promise<void>;
    setDebugOnStart(params: ServiceWorker.setDebugOnStart_Parameters): Promise<void>;
    setForceUpdateOnPageLoad(params: ServiceWorker.setForceUpdateOnPageLoad_Parameters): Promise<void>;
    deliverPushMessage(params: ServiceWorker.deliverPushMessage_Parameters): Promise<void>;
    getTargetInfo(params: ServiceWorker.getTargetInfo_Parameters): Promise<ServiceWorker.getTargetInfo_Return>;
    activateTarget(params: ServiceWorker.activateTarget_Parameters): Promise<void>;
    workerCreated: ServiceWorker.workerCreated_Handler;
    workerTerminated: ServiceWorker.workerTerminated_Handler;
    dispatchMessage: ServiceWorker.dispatchMessage_Handler;
    workerRegistrationUpdated: ServiceWorker.workerRegistrationUpdated_Handler;
    workerVersionUpdated: ServiceWorker.workerVersionUpdated_Handler;
    workerErrorReported: ServiceWorker.workerErrorReported_Handler;
    debugOnStartUpdated: ServiceWorker.debugOnStartUpdated_Handler;
}
export declare namespace ServiceWorker {
    /** ServiceWorker registration. */
    interface ServiceWorkerRegistration {
        registrationId: string;
        scopeURL: string;
        isDeleted: boolean;
        forceUpdateOnPageLoad?: boolean;
    }
    type ServiceWorkerVersionRunningStatus = "stopped" | "starting" | "running" | "stopping";
    type ServiceWorkerVersionStatus = "new" | "installing" | "installed" | "activating" | "activated" | "redundant";
    type TargetID = string;
    /** ServiceWorker version. */
    interface ServiceWorkerVersion {
        versionId: string;
        registrationId: string;
        scriptURL: string;
        runningStatus: ServiceWorkerVersionRunningStatus;
        status: ServiceWorkerVersionStatus;
        /** The Last-Modified header value of the main script. */
        scriptLastModified?: number;
        /** The time at which the response headers of the main script were received from the server.  For cached script it is the last time the cache entry was validated. */
        scriptResponseTime?: number;
        controlledClients?: TargetID[];
    }
    /** ServiceWorker error message. */
    interface ServiceWorkerErrorMessage {
        errorMessage: string;
        registrationId: string;
        versionId: string;
        sourceURL: string;
        lineNumber: number;
        columnNumber: number;
    }
    interface TargetInfo {
        id: TargetID;
        type: string;
        title: string;
        url: string;
    }
    type workerCreated_Parameters = {
        workerId: string;
        url: string;
        versionId: string;
    };
    type workerCreated_Handler = (params: workerCreated_Parameters) => void;
    type workerTerminated_Parameters = {
        workerId: string;
    };
    type workerTerminated_Handler = (params: workerTerminated_Parameters) => void;
    type dispatchMessage_Parameters = {
        workerId: string;
        message: string;
    };
    type dispatchMessage_Handler = (params: dispatchMessage_Parameters) => void;
    type workerRegistrationUpdated_Parameters = {
        registrations: ServiceWorkerRegistration[];
    };
    type workerRegistrationUpdated_Handler = (params: workerRegistrationUpdated_Parameters) => void;
    type workerVersionUpdated_Parameters = {
        versions: ServiceWorkerVersion[];
    };
    type workerVersionUpdated_Handler = (params: workerVersionUpdated_Parameters) => void;
    type workerErrorReported_Parameters = {
        errorMessage: ServiceWorkerErrorMessage;
    };
    type workerErrorReported_Handler = (params: workerErrorReported_Parameters) => void;
    type debugOnStartUpdated_Parameters = {
        debugOnStart: boolean;
    };
    type debugOnStartUpdated_Handler = (params: debugOnStartUpdated_Parameters) => void;
    type sendMessage_Parameters = {
        workerId: string;
        message: string;
    };
    type stop_Parameters = {
        workerId: string;
    };
    type unregister_Parameters = {
        scopeURL: string;
    };
    type updateRegistration_Parameters = {
        scopeURL: string;
    };
    type startWorker_Parameters = {
        scopeURL: string;
    };
    type stopWorker_Parameters = {
        versionId: string;
    };
    type inspectWorker_Parameters = {
        versionId: string;
    };
    type setDebugOnStart_Parameters = {
        debugOnStart: boolean;
    };
    type setForceUpdateOnPageLoad_Parameters = {
        registrationId: string;
        forceUpdateOnPageLoad: boolean;
    };
    type deliverPushMessage_Parameters = {
        origin: string;
        registrationId: string;
        data: string;
    };
    type getTargetInfo_Parameters = {
        targetId: TargetID;
    };
    type getTargetInfo_Return = {
        targetInfo: TargetInfo;
    };
    type activateTarget_Parameters = {
        targetId: TargetID;
    };
}
export declare class Input {
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Dispatches a key event to the page. */
    dispatchKeyEvent(params: Input.dispatchKeyEvent_Parameters): Promise<void>;
    /** Dispatches a mouse event to the page. */
    dispatchMouseEvent(params: Input.dispatchMouseEvent_Parameters): Promise<void>;
    /** Dispatches a touch event to the page. */
    dispatchTouchEvent(params: Input.dispatchTouchEvent_Parameters): Promise<void>;
    /** Emulates touch event from the mouse event parameters. */
    emulateTouchFromMouseEvent(params: Input.emulateTouchFromMouseEvent_Parameters): Promise<void>;
    /** Synthesizes a pinch gesture over a time period by issuing appropriate touch events. */
    synthesizePinchGesture(params: Input.synthesizePinchGesture_Parameters): Promise<void>;
    /** Synthesizes a scroll gesture over a time period by issuing appropriate touch events. */
    synthesizeScrollGesture(params: Input.synthesizeScrollGesture_Parameters): Promise<void>;
    /** Synthesizes a tap gesture over a time period by issuing appropriate touch events. */
    synthesizeTapGesture(params: Input.synthesizeTapGesture_Parameters): Promise<void>;
}
export declare namespace Input {
    interface TouchPoint {
        /** State of the touch point. */
        state: "touchPressed" | "touchReleased" | "touchMoved" | "touchStationary" | "touchCancelled";
        /** X coordinate of the event relative to the main frame's viewport. */
        x: number;
        /** Y coordinate of the event relative to the main frame's viewport. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport. */
        y: number;
        /** X radius of the touch area (default: 1). */
        radiusX?: number;
        /** Y radius of the touch area (default: 1). */
        radiusY?: number;
        /** Rotation angle (default: 0.0). */
        rotationAngle?: number;
        /** Force (default: 1.0). */
        force?: number;
        /** Identifier used to track touch sources between events, must be unique within an event. */
        id?: number;
    }
    type GestureSourceType = "default" | "touch" | "mouse";
    type dispatchKeyEvent_Parameters = {
        /** Type of the key event. */
        type: "keyDown" | "keyUp" | "rawKeyDown" | "char";
        /** Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0). */
        modifiers?: number;
        /** Time at which the event occurred. Measured in UTC time in seconds since January 1, 1970 (default: current time). */
        timestamp?: number;
        /** Text as generated by processing a virtual key code with a keyboard layout. Not needed for for <code>keyUp</code> and <code>rawKeyDown</code> events (default: "") */
        text?: string;
        /** Text that would have been generated by the keyboard if no modifiers were pressed (except for shift). Useful for shortcut (accelerator) key handling (default: ""). */
        unmodifiedText?: string;
        /** Unique key identifier (e.g., 'U+0041') (default: ""). */
        keyIdentifier?: string;
        /** Unique DOM defined string value for each physical key (e.g., 'KeyA') (default: ""). */
        code?: string;
        /** Unique DOM defined string value describing the meaning of the key in the context of active modifiers, keyboard layout, etc (e.g., 'AltGr') (default: ""). */
        key?: string;
        /** Windows virtual key code (default: 0). */
        windowsVirtualKeyCode?: number;
        /** Native virtual key code (default: 0). */
        nativeVirtualKeyCode?: number;
        /** Whether the event was generated from auto repeat (default: false). */
        autoRepeat?: boolean;
        /** Whether the event was generated from the keypad (default: false). */
        isKeypad?: boolean;
        /** Whether the event was a system key event (default: false). */
        isSystemKey?: boolean;
    };
    type dispatchMouseEvent_Parameters = {
        /** Type of the mouse event. */
        type: "mousePressed" | "mouseReleased" | "mouseMoved";
        /** X coordinate of the event relative to the main frame's viewport. */
        x: number;
        /** Y coordinate of the event relative to the main frame's viewport. 0 refers to the top of the viewport and Y increases as it proceeds towards the bottom of the viewport. */
        y: number;
        /** Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0). */
        modifiers?: number;
        /** Time at which the event occurred. Measured in UTC time in seconds since January 1, 1970 (default: current time). */
        timestamp?: number;
        /** Mouse button (default: "none"). */
        button?: "none" | "left" | "middle" | "right";
        /** Number of times the mouse button was clicked (default: 0). */
        clickCount?: number;
    };
    type dispatchTouchEvent_Parameters = {
        /** Type of the touch event. */
        type: "touchStart" | "touchEnd" | "touchMove";
        /** Touch points. */
        touchPoints: TouchPoint[];
        /** Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0). */
        modifiers?: number;
        /** Time at which the event occurred. Measured in UTC time in seconds since January 1, 1970 (default: current time). */
        timestamp?: number;
    };
    type emulateTouchFromMouseEvent_Parameters = {
        /** Type of the mouse event. */
        type: "mousePressed" | "mouseReleased" | "mouseMoved" | "mouseWheel";
        /** X coordinate of the mouse pointer in DIP. */
        x: number;
        /** Y coordinate of the mouse pointer in DIP. */
        y: number;
        /** Time at which the event occurred. Measured in UTC time in seconds since January 1, 1970. */
        timestamp: number;
        /** Mouse button. */
        button: "none" | "left" | "middle" | "right";
        /** X delta in DIP for mouse wheel event (default: 0). */
        deltaX?: number;
        /** Y delta in DIP for mouse wheel event (default: 0). */
        deltaY?: number;
        /** Bit field representing pressed modifier keys. Alt=1, Ctrl=2, Meta/Command=4, Shift=8 (default: 0). */
        modifiers?: number;
        /** Number of times the mouse button was clicked (default: 0). */
        clickCount?: number;
    };
    type synthesizePinchGesture_Parameters = {
        /** X coordinate of the start of the gesture in CSS pixels. */
        x: number;
        /** Y coordinate of the start of the gesture in CSS pixels. */
        y: number;
        /** Relative scale factor after zooming (>1.0 zooms in, <1.0 zooms out). */
        scaleFactor: number;
        /** Relative pointer speed in pixels per second (default: 800). */
        relativeSpeed?: number;
        /** Which type of input events to be generated (default: 'default', which queries the platform for the preferred input type). */
        gestureSourceType?: GestureSourceType;
    };
    type synthesizeScrollGesture_Parameters = {
        /** X coordinate of the start of the gesture in CSS pixels. */
        x: number;
        /** Y coordinate of the start of the gesture in CSS pixels. */
        y: number;
        /** The distance to scroll along the X axis (positive to scroll left). */
        xDistance?: number;
        /** The distance to scroll along the Y axis (positive to scroll up). */
        yDistance?: number;
        /** The number of additional pixels to scroll back along the X axis, in addition to the given distance. */
        xOverscroll?: number;
        /** The number of additional pixels to scroll back along the Y axis, in addition to the given distance. */
        yOverscroll?: number;
        /** Prevent fling (default: true). */
        preventFling?: boolean;
        /** Swipe speed in pixels per second (default: 800). */
        speed?: number;
        /** Which type of input events to be generated (default: 'default', which queries the platform for the preferred input type). */
        gestureSourceType?: GestureSourceType;
        /** The number of times to repeat the gesture (default: 0). */
        repeatCount?: number;
        /** The number of milliseconds delay between each repeat. (default: 250). */
        repeatDelayMs?: number;
        /** The name of the interaction markers to generate, if not empty (default: ""). */
        interactionMarkerName?: string;
    };
    type synthesizeTapGesture_Parameters = {
        /** X coordinate of the start of the gesture in CSS pixels. */
        x: number;
        /** Y coordinate of the start of the gesture in CSS pixels. */
        y: number;
        /** Duration between touchdown and touchup events in ms (default: 50). */
        duration?: number;
        /** Number of times to perform the tap (e.g. 2 for double tap, default: 1). */
        tapCount?: number;
        /** Which type of input events to be generated (default: 'default', which queries the platform for the preferred input type). */
        gestureSourceType?: GestureSourceType;
    };
}
export declare class LayerTree {
    private _layerTreeDidChange;
    private _layerPainted;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Enables compositing tree inspection. */
    enable(): Promise<void>;
    /** Disables compositing tree inspection. */
    disable(): Promise<void>;
    /** Provides the reasons why the given layer was composited. */
    compositingReasons(params: LayerTree.compositingReasons_Parameters): Promise<LayerTree.compositingReasons_Return>;
    /** Returns the layer snapshot identifier. */
    makeSnapshot(params: LayerTree.makeSnapshot_Parameters): Promise<LayerTree.makeSnapshot_Return>;
    /** Returns the snapshot identifier. */
    loadSnapshot(params: LayerTree.loadSnapshot_Parameters): Promise<LayerTree.loadSnapshot_Return>;
    /** Releases layer snapshot captured by the back-end. */
    releaseSnapshot(params: LayerTree.releaseSnapshot_Parameters): Promise<void>;
    profileSnapshot(params: LayerTree.profileSnapshot_Parameters): Promise<LayerTree.profileSnapshot_Return>;
    /** Replays the layer snapshot and returns the resulting bitmap. */
    replaySnapshot(params: LayerTree.replaySnapshot_Parameters): Promise<LayerTree.replaySnapshot_Return>;
    /** Replays the layer snapshot and returns canvas log. */
    snapshotCommandLog(params: LayerTree.snapshotCommandLog_Parameters): Promise<LayerTree.snapshotCommandLog_Return>;
    layerTreeDidChange: LayerTree.layerTreeDidChange_Handler;
    layerPainted: LayerTree.layerPainted_Handler;
}
export declare namespace LayerTree {
    /** Unique Layer identifier. */
    type LayerId = string;
    /** Unique snapshot identifier. */
    type SnapshotId = string;
    /** Rectangle where scrolling happens on the main thread. */
    interface ScrollRect {
        /** Rectangle itself. */
        rect: DOM.Rect;
        /** Reason for rectangle to force scrolling on the main thread */
        type: "RepaintsOnScroll" | "TouchEventHandler" | "WheelEventHandler";
    }
    /** Serialized fragment of layer picture along with its offset within the layer. */
    interface PictureTile {
        /** Offset from owning layer left boundary */
        x: number;
        /** Offset from owning layer top boundary */
        y: number;
        /** Base64-encoded snapshot data. */
        picture: string;
    }
    /** Information about a compositing layer. */
    interface Layer {
        /** The unique id for this layer. */
        layerId: LayerId;
        /** The id of parent (not present for root). */
        parentLayerId?: LayerId;
        /** The backend id for the node associated with this layer. */
        backendNodeId?: DOM.BackendNodeId;
        /** Offset from parent layer, X coordinate. */
        offsetX: number;
        /** Offset from parent layer, Y coordinate. */
        offsetY: number;
        /** Layer width. */
        width: number;
        /** Layer height. */
        height: number;
        /** Transformation matrix for layer, default is identity matrix */
        transform?: number[];
        /** Transform anchor point X, absent if no transform specified */
        anchorX?: number;
        /** Transform anchor point Y, absent if no transform specified */
        anchorY?: number;
        /** Transform anchor point Z, absent if no transform specified */
        anchorZ?: number;
        /** Indicates how many time this layer has painted. */
        paintCount: number;
        /** Indicates whether this layer hosts any content, rather than being used for transform/scrolling purposes only. */
        drawsContent: boolean;
        /** Set if layer is not visible. */
        invisible?: boolean;
        /** Rectangles scrolling on main thread only. */
        scrollRects?: ScrollRect[];
    }
    /** Array of timings, one per paint step. */
    type PaintProfile = number[];
    type layerTreeDidChange_Parameters = {
        /** Layer tree, absent if not in the comspositing mode. */
        layers?: Layer[];
    };
    type layerTreeDidChange_Handler = (params: layerTreeDidChange_Parameters) => void;
    type layerPainted_Parameters = {
        /** The id of the painted layer. */
        layerId: LayerId;
        /** Clip rectangle. */
        clip: DOM.Rect;
    };
    type layerPainted_Handler = (params: layerPainted_Parameters) => void;
    type compositingReasons_Parameters = {
        /** The id of the layer for which we want to get the reasons it was composited. */
        layerId: LayerId;
    };
    type compositingReasons_Return = {
        /** A list of strings specifying reasons for the given layer to become composited. */
        compositingReasons: string[];
    };
    type makeSnapshot_Parameters = {
        /** The id of the layer. */
        layerId: LayerId;
    };
    type makeSnapshot_Return = {
        /** The id of the layer snapshot. */
        snapshotId: SnapshotId;
    };
    type loadSnapshot_Parameters = {
        /** An array of tiles composing the snapshot. */
        tiles: PictureTile[];
    };
    type loadSnapshot_Return = {
        /** The id of the snapshot. */
        snapshotId: SnapshotId;
    };
    type releaseSnapshot_Parameters = {
        /** The id of the layer snapshot. */
        snapshotId: SnapshotId;
    };
    type profileSnapshot_Parameters = {
        /** The id of the layer snapshot. */
        snapshotId: SnapshotId;
        /** The maximum number of times to replay the snapshot (1, if not specified). */
        minRepeatCount?: number;
        /** The minimum duration (in seconds) to replay the snapshot. */
        minDuration?: number;
        /** The clip rectangle to apply when replaying the snapshot. */
        clipRect?: DOM.Rect;
    };
    type profileSnapshot_Return = {
        /** The array of paint profiles, one per run. */
        timings: PaintProfile[];
    };
    type replaySnapshot_Parameters = {
        /** The id of the layer snapshot. */
        snapshotId: SnapshotId;
        /** The first step to replay from (replay from the very start if not specified). */
        fromStep?: number;
        /** The last step to replay to (replay till the end if not specified). */
        toStep?: number;
        /** The scale to apply while replaying (defaults to 1). */
        scale?: number;
    };
    type replaySnapshot_Return = {
        /** A data: URL for resulting image. */
        dataURL: string;
    };
    type snapshotCommandLog_Parameters = {
        /** The id of the layer snapshot. */
        snapshotId: SnapshotId;
    };
    type snapshotCommandLog_Return = {
        /** The array of canvas function calls. */
        commandLog: any[];
    };
}
export declare class DeviceOrientation {
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Overrides the Device Orientation. */
    setDeviceOrientationOverride(params: DeviceOrientation.setDeviceOrientationOverride_Parameters): Promise<void>;
    /** Clears the overridden Device Orientation. */
    clearDeviceOrientationOverride(): Promise<void>;
}
export declare namespace DeviceOrientation {
    type setDeviceOrientationOverride_Parameters = {
        /** Mock alpha */
        alpha: number;
        /** Mock beta */
        beta: number;
        /** Mock gamma */
        gamma: number;
    };
}
export declare class ScreenOrientation {
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Overrides the Screen Orientation. */
    setScreenOrientationOverride(params: ScreenOrientation.setScreenOrientationOverride_Parameters): Promise<void>;
    /** Clears the overridden Screen Orientation. */
    clearScreenOrientationOverride(): Promise<void>;
}
export declare namespace ScreenOrientation {
    /** Orientation type */
    type OrientationType = "portraitPrimary" | "portraitSecondary" | "landscapePrimary" | "landscapeSecondary";
    type setScreenOrientationOverride_Parameters = {
        /** Orientation angle */
        angle: number;
        /** Orientation type */
        type: OrientationType;
    };
}
export declare class Tracing {
    private _dataCollected;
    private _tracingComplete;
    private _bufferUsage;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Start trace events collection. */
    start(params: Tracing.start_Parameters): Promise<void>;
    /** Stop trace events collection. */
    end(): Promise<void>;
    /** Gets supported tracing categories. */
    getCategories(): Promise<Tracing.getCategories_Return>;
    /** Request a global memory dump. */
    requestMemoryDump(): Promise<Tracing.requestMemoryDump_Return>;
    /** Contains an bucket of collected trace events. When tracing is stopped collected events will be send as a sequence of dataCollected events followed by tracingComplete event. */
    dataCollected: Tracing.dataCollected_Handler;
    /** Signals that tracing is stopped and there is no trace buffers pending flush, all data were delivered via dataCollected events. */
    tracingComplete: Tracing.tracingComplete_Handler;
    bufferUsage: Tracing.bufferUsage_Handler;
}
export declare namespace Tracing {
    type dataCollected_Parameters = {
        value: any[];
    };
    type dataCollected_Handler = (params: dataCollected_Parameters) => void;
    type tracingComplete_Parameters = {
        /** A handle of the stream that holds resulting trace data. */
        stream?: IO.StreamHandle;
    };
    type tracingComplete_Handler = (params: tracingComplete_Parameters) => void;
    type bufferUsage_Parameters = {
        /** A number in range [0..1] that indicates the used size of event buffer as a fraction of its total size. */
        percentFull?: number;
        /** An approximate number of events in the trace log. */
        eventCount?: number;
        /** A number in range [0..1] that indicates the used size of event buffer as a fraction of its total size. */
        value?: number;
    };
    type bufferUsage_Handler = (params: bufferUsage_Parameters) => void;
    type start_Parameters = {
        /** Category/tag filter */
        categories?: string;
        /** Tracing options */
        options?: string;
        /** If set, the agent will issue bufferUsage events at this interval, specified in milliseconds */
        bufferUsageReportingInterval?: number;
        /** Whether to report trace events as series of dataCollected events or to save trace to a stream (defaults to <code>ReportEvents</code>). */
        transferMode?: "ReportEvents" | "ReturnAsStream";
    };
    type getCategories_Return = {
        /** A list of supported tracing categories. */
        categories: string[];
    };
    type requestMemoryDump_Return = {
        /** GUID of the resulting global memory dump. */
        dumpGuid: string;
        /** True iff the global memory dump succeeded. */
        success: boolean;
    };
}
export declare class Animation {
    private _animationCreated;
    private _animationStarted;
    private _animationCanceled;
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Enables animation domain notifications. */
    enable(): Promise<void>;
    /** Disables animation domain notifications. */
    disable(): Promise<void>;
    /** Gets the playback rate of the document timeline. */
    getPlaybackRate(): Promise<Animation.getPlaybackRate_Return>;
    /** Sets the playback rate of the document timeline. */
    setPlaybackRate(params: Animation.setPlaybackRate_Parameters): Promise<void>;
    /** Returns the current time of the an animation. */
    getCurrentTime(params: Animation.getCurrentTime_Parameters): Promise<Animation.getCurrentTime_Return>;
    /** Sets the paused state of a set of animations. */
    setPaused(params: Animation.setPaused_Parameters): Promise<void>;
    /** Sets the timing of an animation node. */
    setTiming(params: Animation.setTiming_Parameters): Promise<void>;
    /** Seek a set of animations to a particular time within each animation. */
    seekAnimations(params: Animation.seekAnimations_Parameters): Promise<void>;
    /** Releases a set of animations to no longer be manipulated. */
    releaseAnimations(params: Animation.releaseAnimations_Parameters): Promise<void>;
    /** Gets the remote object of the Animation. */
    resolveAnimation(params: Animation.resolveAnimation_Parameters): Promise<Animation.resolveAnimation_Return>;
    /** Event for each animation that has been created. */
    animationCreated: Animation.animationCreated_Handler;
    /** Event for animation that has been started. */
    animationStarted: Animation.animationStarted_Handler;
    /** Event for when an animation has been cancelled. */
    animationCanceled: Animation.animationCanceled_Handler;
}
export declare namespace Animation {
    /** Animation instance. */
    interface Animation {
        /** <code>Animation</code>'s id. */
        id: string;
        /** <code>Animation</code>'s internal paused state. */
        pausedState: boolean;
        /** <code>Animation</code>'s play state. */
        playState: string;
        /** <code>Animation</code>'s playback rate. */
        playbackRate: number;
        /** <code>Animation</code>'s start time. */
        startTime: number;
        /** <code>Animation</code>'s current time. */
        currentTime: number;
        /** <code>Animation</code>'s source animation node. */
        source: AnimationEffect;
        /** Animation type of <code>Animation</code>. */
        type: "CSSTransition" | "CSSAnimation" | "WebAnimation";
        /** A unique ID for <code>Animation</code> representing the sources that triggered this CSS animation/transition. */
        cssId?: string;
    }
    /** AnimationEffect instance */
    interface AnimationEffect {
        /** <code>AnimationEffect</code>'s delay. */
        delay: number;
        /** <code>AnimationEffect</code>'s end delay. */
        endDelay: number;
        /** <code>AnimationEffect</code>'s playbackRate. */
        playbackRate: number;
        /** <code>AnimationEffect</code>'s iteration start. */
        iterationStart: number;
        /** <code>AnimationEffect</code>'s iterations. */
        iterations: number;
        /** <code>AnimationEffect</code>'s iteration duration. */
        duration: number;
        /** <code>AnimationEffect</code>'s playback direction. */
        direction: string;
        /** <code>AnimationEffect</code>'s fill mode. */
        fill: string;
        /** <code>AnimationEffect</code>'s name. */
        name: string;
        /** <code>AnimationEffect</code>'s target node. */
        backendNodeId: DOM.BackendNodeId;
        /** <code>AnimationEffect</code>'s keyframes. */
        keyframesRule?: KeyframesRule;
        /** <code>AnimationEffect</code>'s timing function. */
        easing: string;
    }
    /** Keyframes Rule */
    interface KeyframesRule {
        /** CSS keyframed animation's name. */
        name?: string;
        /** List of animation keyframes. */
        keyframes: KeyframeStyle[];
    }
    /** Keyframe Style */
    interface KeyframeStyle {
        /** Keyframe's time offset. */
        offset: string;
        /** <code>AnimationEffect</code>'s timing function. */
        easing: string;
    }
    type animationCreated_Parameters = {
        /** Id of the animation that was created. */
        id: string;
    };
    type animationCreated_Handler = (params: animationCreated_Parameters) => void;
    type animationStarted_Parameters = {
        /** Animation that was started. */
        animation: Animation;
    };
    type animationStarted_Handler = (params: animationStarted_Parameters) => void;
    type animationCanceled_Parameters = {
        /** Id of the animation that was cancelled. */
        id: string;
    };
    type animationCanceled_Handler = (params: animationCanceled_Parameters) => void;
    type getPlaybackRate_Return = {
        /** Playback rate for animations on page. */
        playbackRate: number;
    };
    type setPlaybackRate_Parameters = {
        /** Playback rate for animations on page */
        playbackRate: number;
    };
    type getCurrentTime_Parameters = {
        /** Id of animation. */
        id: string;
    };
    type getCurrentTime_Return = {
        /** Current time of the page. */
        currentTime: number;
    };
    type setPaused_Parameters = {
        /** Animations to set the pause state of. */
        animations: string[];
        /** Paused state to set to. */
        paused: boolean;
    };
    type setTiming_Parameters = {
        /** Animation id. */
        animationId: string;
        /** Duration of the animation. */
        duration: number;
        /** Delay of the animation. */
        delay: number;
    };
    type seekAnimations_Parameters = {
        /** List of animation ids to seek. */
        animations: string[];
        /** Set the current time of each animation. */
        currentTime: number;
    };
    type releaseAnimations_Parameters = {
        /** List of animation ids to seek. */
        animations: string[];
    };
    type resolveAnimation_Parameters = {
        /** Animation id. */
        animationId: string;
    };
    type resolveAnimation_Return = {
        /** Corresponding remote object. */
        remoteObject: Runtime.RemoteObject;
    };
}
export declare class Accessibility {
    private _client;
    constructor(client: IDebuggingProtocolClient);
    /** Fetches the accessibility node for this DOM node, if it exists. */
    getAXNode(params: Accessibility.getAXNode_Parameters): Promise<Accessibility.getAXNode_Return>;
}
export declare namespace Accessibility {
    /** Unique accessibility node identifier. */
    type AXNodeId = string;
    /** Enum of possible property types. */
    type AXValueType = "boolean" | "tristate" | "booleanOrUndefined" | "idref" | "idrefList" | "integer" | "node" | "nodeList" | "number" | "string" | "computedString" | "token" | "tokenList" | "domRelation" | "role" | "internalRole" | "valueUndefined";
    /** Enum of possible property sources. */
    type AXValueSourceType = "attribute" | "implicit" | "style" | "contents" | "placeholder" | "relatedElement";
    /** Enum of possible native property sources (as a subtype of a particular AXValueSourceType). */
    type AXValueNativeSourceType = "figcaption" | "label" | "labelfor" | "labelwrapped" | "legend" | "tablecaption" | "title" | "other";
    /** A single source for a computed AX property. */
    interface AXValueSource {
        /** What type of source this is. */
        type: AXValueSourceType;
        /** The value of this property source. */
        value?: AXValue;
        /** The attribute, if any. */
        attribute?: string;
        /** Whether this source is superseded by a higher priority source. */
        superseded?: boolean;
        /** The native markup source for this value, e.g. a <label> element. */
        nativeSource?: AXValueNativeSourceType;
        /** Whether the value for this property is invalid. */
        invalid?: boolean;
        /** Reason for the value being invalid, if it is. */
        invalidReason?: string;
    }
    interface AXRelatedNode {
        /** The BackendNodeId of the related node. */
        backendNodeId: DOM.BackendNodeId;
        /** The IDRef value provided, if any. */
        idref?: string;
        /** The text alternative of this node in the current context. */
        text?: string;
    }
    interface AXProperty {
        /** The name of this property. */
        name: string;
        /** The value of this property. */
        value: AXValue;
    }
    /** A single computed AX property. */
    interface AXValue {
        /** The type of this value. */
        type: AXValueType;
        /** The computed value of this property. */
        value?: any;
        /** One or more related nodes, if applicable. */
        relatedNodes?: AXRelatedNode[];
        /** The sources which contributed to the computation of this property. */
        sources?: AXValueSource[];
    }
    /** States which apply to every AX node. */
    type AXGlobalStates = "disabled" | "hidden" | "hiddenRoot" | "invalid";
    /** Attributes which apply to nodes in live regions. */
    type AXLiveRegionAttributes = "live" | "atomic" | "relevant" | "busy" | "root";
    type AXWidgetAttributes = "autocomplete" | "haspopup" | "level" | "multiselectable" | "orientation" | "multiline" | "readonly" | "required" | "valuemin" | "valuemax" | "valuetext";
    /** States which apply to widgets. */
    type AXWidgetStates = "checked" | "expanded" | "pressed" | "selected";
    /** Relationships between elements other than parent/child/sibling. */
    type AXRelationshipAttributes = "activedescendant" | "flowto" | "controls" | "describedby" | "labelledby" | "owns";
    /** A node in the accessibility tree. */
    interface AXNode {
        /** Unique identifier for this node. */
        nodeId: AXNodeId;
        /** Whether this node is ignored for accessibility */
        ignored: boolean;
        /** Collection of reasons why this node is hidden. */
        ignoredReasons?: AXProperty[];
        /** This <code>Node</code>'s role, whether explicit or implicit. */
        role?: AXValue;
        /** The accessible name for this <code>Node</code>. */
        name?: AXValue;
        /** The accessible description for this <code>Node</code>. */
        description?: AXValue;
        /** The value for this <code>Node</code>. */
        value?: AXValue;
        /** All other properties */
        properties?: AXProperty[];
    }
    type getAXNode_Parameters = {
        /** ID of node to get accessibility node for. */
        nodeId: DOM.NodeId;
    };
    type getAXNode_Return = {
        /** The <code>Accessibility.AXNode</code> for this DOM node, if it exists. */
        accessibilityNode?: AXNode;
    };
}
