"use strict";
const process_1 = require("./process");
const bounds_1 = require("./bounds");
const trace_event_1 = require("./trace_event");
class Trace {
    constructor() {
        this.processMap = {};
        this.processes = [];
        this.bounds = new bounds_1.default();
        this.events = [];
        this.browserProcess = null;
        this.gpuProcess = null;
        this.rendererProcesses = [];
    }
    process(pid) {
        let process = this.processMap[pid];
        if (process === undefined) {
            this.processMap[pid] = process = new process_1.default(pid);
            this.processes.push(process);
        }
        return process;
    }
    thread(pid, tid) {
        return this.process(pid).thread(tid);
    }
    addEvents(events) {
        for (let i = 0; i < events.length; i++) {
            this.addEvent(events[i]);
        }
    }
    addEvent(event) {
        this.events.push(event);
        if (event.ph === trace_event_1.TRACE_EVENT_PHASE_METADATA) {
            this.addMetadata(event);
            return;
        }
        this.bounds.addEvent(event);
        this.process(event.pid).addEvent(event);
    }
    addMetadata(event) {
        let pid = event.pid;
        let tid = event.tid;
        switch (event.name) {
            case "num_cpus":
                this.numberOfProcessors = event.args["number"];
                break;
            case "process_name":
                let process_name = event.args["name"];
                let process = this.process(pid);
                process.name = process_name;
                if (process_name === "GPU Process") {
                    this.gpuProcess = process;
                }
                else if (process_name === "Browser") {
                    this.browserProcess = process;
                }
                else if (process_name === "Renderer") {
                    this.rendererProcesses.push(process);
                }
                break;
            case "process_labels":
                this.process(pid).labels = event.args["labels"];
                break;
            case "process_sort_index":
                this.process(pid).sortIndex = event.args["sort_index"];
                break;
            case "trace_buffer_overflowed":
                this.process(pid).traceBufferOverflowedAt = event.args["overflowed_at_ts"];
                break;
            case "thread_name":
                let thread_name = event.args["name"];
                let thread = this.thread(pid, tid);
                thread.name = thread_name;
                if (thread_name.endsWith("Main")) {
                    this.process(pid).mainThread = thread;
                }
                break;
            case "thread_sort_index":
                this.thread(pid, tid).sortIndex = event.args["sort_index"];
                break;
            case "IsTimeTicksHighResolution":
                this.process(pid).isTimeTicksHighResolution = event.args["value"];
                break;
            case "TraceConfig":
                this.process(pid).traceConfig = event.args["value"];
                break;
            default:
                console.warn("unrecognized metadata:", JSON.stringify(event, null, 2));
                break;
        }
    }
}
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = Trace;
//# sourceMappingURL=trace.js.map